@@ -52,14 +52,14 @@ package com.openexchange.guard.cipher.osgi;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
-import com.openexchange.guard.cipher.internal.BouncyCastlerCryptoInitializer;
+import com.openexchange.guard.cipher.internal.BouncyCastleCryptoInitializer;
 import com.openexchange.guard.cipher.internal.GuardCipherFactoryServiceImpl;
 import com.openexchange.guard.cipher.internal.GuardCryptoInitializer;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.configuration.validation.ConfigurationValidator;
-import com.openexchange.guard.inputvalidation.IntegerRangeInputValidator;
-import com.openexchange.guard.inputvalidation.InvalidValueHandler;
+import com.openexchange.guard.configuration.validation.InvalidValueHandler;
+import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.inputvalidation.WhiteListInputValidator;
 import com.openexchange.osgi.HousekeepingActivator;
 
@@ -72,7 +72,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.DeferredActivator#getNeededServices()
      */
     @Override
@@ -82,7 +82,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.DeferredActivator#startBundle()
      */
     @Override
@@ -91,7 +91,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
         logger.info("Starting bundle {}", context.getBundle().getSymbolicName());
 
         //Registering bouncy castle provider
-        GuardCryptoInitializer cryptoInitializer = new BouncyCastlerCryptoInitializer();
+        GuardCryptoInitializer cryptoInitializer = new BouncyCastleCryptoInitializer();
         cryptoInitializer.initialize();
 
         Services.setServiceLookup(this);
@@ -105,7 +105,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
         //Validate that the configured AES key length is a valid AES key length
         validator.assertValue(GuardProperty.aesKeyLength,
             Integer.class,
-            new WhiteListInputValidator<Integer>(new Integer[] { 128, 192, 256 }),
+            new WhiteListInputValidator<>(new Integer[] { 128, 192, 256 }),
             new InvalidValueHandler<Integer>() {
 
                 @Override
@@ -121,7 +121,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
         //about up to the key length and OX Guard requires at least about 1024 bit.
         validator.assertValue(GuardProperty.rsaKeyLength,
             Integer.class,
-            new IntegerRangeInputValidator(1024, Integer.MAX_VALUE),
+            new RangeInputValidator<Integer>(1024, Integer.MAX_VALUE),
             new InvalidValueHandler<Integer>() {
 
                 @Override
@@ -138,7 +138,7 @@ public class GuardCipherActivator extends HousekeepingActivator {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.HousekeepingActivator#stopBundle()
      */
     @Override
