@@ -73,13 +73,13 @@ import javax.management.remote.JMXConnectorFactory;
 import javax.management.remote.JMXServiceURL;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Options;
-import com.google.gson.JsonObject;
-import com.google.gson.JsonParser;
 import com.openexchange.auth.rmi.RemoteAuthenticator;
 import com.openexchange.cli.AbstractRmiCLI;
+import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.management.maintenance.GuardMaintenanceMBean;
+import com.openexchange.guard.management.maintenance.internal.TestUserResult;
 
 /**
  * {@link Guard}
@@ -89,13 +89,13 @@ import com.openexchange.guard.management.maintenance.GuardMaintenanceMBean;
  */
 public class Guard extends AbstractRmiCLI<Void> {
 
-    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x' };
+    private final char[] optionsWithArgs = { 't', 'e', 'n', 'u', 'j', 'w', 'o', 'x', 'g' };
 
     private static final String serviceURL = "service:jmx:rmi:///jndi/rmi://";
 
     private static final String DEFAULT_CONF_FOLDER = "/opt/open-xchange/etc";
 
-    private boolean requiresAuth;
+    private final boolean requiresAuth;
 
     /**
      * @param args
@@ -109,21 +109,25 @@ public class Guard extends AbstractRmiCLI<Void> {
      */
 
     public Guard(String[] args) {
-    	super();
-    	requiresAuth = needsAuth(args);
+        super();
+        requiresAuth = needsAuth(args);
     }
 
     /**
      * Return true if ags includes action that requires authentication
+     * 
      * @param args
      * @return
      */
-    private boolean needsAuth (String[] args) {
-    	for (String arg : args) {
-    		if (arg.trim().equals("-D") || arg.trim().equals("--delete")) return true;
-    	}
-    	return false;
+    private boolean needsAuth(String[] args) {
+        for (String arg : args) {
+            if (arg.trim().equals("-D") || arg.trim().equals("--delete")) {
+                return true;
+            }
+        }
+        return false;
     }
+
     /*
      * (non-Javadoc)
      *
@@ -131,7 +135,7 @@ public class Guard extends AbstractRmiCLI<Void> {
      */
     @Override
     protected void administrativeAuth(String login, String password, CommandLine cmd, RemoteAuthenticator authenticator) throws RemoteException {
-    	authenticator.doAuthentication(login, password);
+        authenticator.doAuthentication(login, password);
     }
 
     /*
@@ -148,6 +152,7 @@ public class Guard extends AbstractRmiCLI<Void> {
         options.addOption("n", "remove-pin", true, "Removes the PIN for the specified user\ne.g. guard --remove-pin john@somewhere.com");
         options.addOption("u", "upgrade", true, "Upgrades the specified guest account to an OX account\ne.g. guard --upgrade john@somewhere.com");
         options.addOption("D", "delete", true, "Deletes a specified Guard user");
+        options.addOption("g", "guestreset", true, "Reset a Guest account.  Creates new keys for the user.  If has password recovery, must specify force to reset account.\ne.g. guard --g john@somewhere [-f]");
         options.addOption("j", "jmx-user", true, "JMX user");
         options.addOption("w", "jmx-password", true, "JMX password");
         options.addOption("o", "jmx-port", true, "JMX port (default: '9999')");
@@ -209,16 +214,23 @@ public class Guard extends AbstractRmiCLI<Void> {
             } else if (cmd.hasOption('t')) {
                 String email = cmd.getOptionValue('t');
                 test(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
+            } else if (cmd.hasOption('g')) {
+                String email = cmd.getOptionValue('g');
+                resetGuest(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email, cmd.hasOption('f'));
             } else if (cmd.hasOption('D')) {
-            	String email = cmd.getOptionValue('D');
-            	delete(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
+                String email = cmd.getOptionValue('D');
+                delete(createProxy(jmxHost, jmxPort, jmxUser, jmxPassword), email);
             } else {
                 printHelp(options);
                 System.exit(0);
             }
         } catch (Exception e) {
-            System.err.println("Operation failed.\n");
-            e.printStackTrace();
+            if (e.getCause() instanceof OXException) {
+                System.err.println(e.getCause().getMessage());
+            } else {
+                System.err.println("Operation failed.\n");
+                e.printStackTrace();
+            }
             System.exit(-1);
         }
         return null;
@@ -245,26 +257,22 @@ public class Guard extends AbstractRmiCLI<Void> {
         System.out.println(String.format("Guest (%s) has been upgraded.", email));
     }
 
-    private void delete (GuardMaintenanceMBean proxy, String email) throws MBeanException {
-    	proxy.deleteUser(email);
-    	System.out.println(String.format("User (%s) has been deleted.", email));
+    private void delete(GuardMaintenanceMBean proxy, String email) throws MBeanException {
+        proxy.deleteUser(email);
+        System.out.println(String.format("User (%s) has been deleted.", email));
+    }
+
+    private void resetGuest(GuardMaintenanceMBean proxy, String email, boolean force) throws MBeanException {
+        proxy.reset(email);
+        System.out.println(String.format("Guest (%s) has been reset.", email));
     }
 
     private void test(GuardMaintenanceMBean proxy, String email) throws MBeanException {
-        String jsonResponse = proxy.test(email);
-        JsonObject userdat = new JsonParser().parse(jsonResponse).getAsJsonObject();
-
-        StringBuilder sb = new StringBuilder();
-        sb.append("Response received.  Testing JSON\n");
-        sb.append(userdat.toString()).append("\n");
-        final JsonObject euser = userdat.get(email).getAsJsonObject();
-        sb.append("User id ").append(euser.get("uid").getAsInt()).append("\n");
-        sb.append("Context ").append(euser.get("cid").getAsInt()).append("\n");
-        sb.append("Language ").append(euser.get("user").getAsJsonObject().get("language").getAsString()).append("\n");
-        sb.append("Name ").append(euser.get("user").getAsJsonObject().get("displayName").getAsString()).append("\n");
-        sb.append("Success").append("\n");
-
-        System.out.println(sb.toString());
+        TestUserResult testResult = proxy.testUser(email);
+        System.out.println("User id: " + testResult.getUserId());
+        System.out.println("Context: " + testResult.getContextId());
+        System.out.println("Language: " + testResult.getLanguageString());
+        System.out.println("Name: " + testResult.getDisplayName());
     }
 
     /*
