@@ -7,6 +7,8 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonParser;
+import com.fasterxml.jackson.core.JsonProcessingException;
+import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.gson.JsonArray;
 import com.google.gson.stream.JsonReader;
 import com.openexchange.exception.OXException;
@@ -21,7 +23,7 @@ public final class JsonUtil {
 
     /**
      * Utility to extract JSON data from a web response
-     * 
+     *
      * @param webResponse the response to extract data from
      * @return The parsed JSON object
      */
@@ -36,14 +38,14 @@ public final class JsonUtil {
 
     /**
      * Parses the specified data as JsonObject
-     * 
+     *
      * @param data
      * @return
      * @throws IllegalArgumentException if the specified data cannot be parsed as a JsonObject
      */
     public static JsonObject parseAsJsonObject(String data) {
         JsonParser jsonParser = new JsonParser();
-        JsonElement element = jsonParser.parse(data);
+        JsonElement element = jsonParser.parse(data.trim());
         if (!element.isJsonNull() && element.isJsonObject()) {
             return element.getAsJsonObject();
         }
@@ -52,7 +54,7 @@ public final class JsonUtil {
 
     /**
      * Checks if the data is a valid, parsable JSON
-     * 
+     *
      * @param data The data which should be checked
      * @return True, if the data is valid JSON, False otherwise
      */
@@ -71,7 +73,7 @@ public final class JsonUtil {
     }
 
     /**
-     * 
+     *
      * @param json
      * @param name
      * @return
@@ -83,7 +85,7 @@ public final class JsonUtil {
 
     /**
      * Get String from JsonObject
-     * 
+     *
      * @param json
      * @param name
      * @param mandatory
@@ -107,18 +109,7 @@ public final class JsonUtil {
     }
 
     /**
-     * 
-     * @param json
-     * @param name
-     * @return
-     * @throws OXException
-     */
-    public static int getIntFromJson(JsonObject json, String name) throws OXException {
-        return getIntFromJson(json, name, false);
-    }
-
-    /**
-     * 
+     *
      * @param json
      * @param name
      * @return
@@ -129,7 +120,7 @@ public final class JsonUtil {
     }
 
     /**
-     * 
+     *
      * @param json
      * @param name
      * @param mandatory
@@ -153,20 +144,20 @@ public final class JsonUtil {
     }
 
     /**
-     * Get int from JsonObject
-     * 
-     * @param json
-     * @param name
-     * @param mandatory
-     * @return
-     * @throws OXException
+     * Gets an integer parameter from the given JsonObject.
+     *
+     * @param json The JSON object.
+     * @param name The name of the integer parameter.
+     * @param mandatory true, to throw an exception if the parameter was not found, false to return null.
+     * @return The parameter's value or null if the parameter was not found and mandatory is set to false.
+     * @throws OXException If the parameter was not found and mandatory is set to true.
      */
-    public static int getIntFromJson(JsonObject json, String name, boolean mandatory) throws OXException {
+    public static Integer getIntFromJson(JsonObject json, String name, boolean mandatory) throws OXException {
         if (!json.has(name)) {
             if (mandatory) {
                 throw GuardCoreExceptionCodes.JSON_PARAMETER_MISSING.create(name);
             } else {
-                return 0;
+                return null;
             }
         }
         try {
@@ -176,11 +167,22 @@ public final class JsonUtil {
             throw GuardCoreExceptionCodes.JSON_ERROR.create(ex, ex.getMessage());
         }
     }
-    
+
+    /**
+     * Gets an integer parameter form the given JsonObject
+     * @param json The JSON Object
+     * @param name The nname of the integer parameter.
+     * @return The parameter's value or null if the paramter was not found.
+     * @throws OXException
+     */
+    public static Integer getIntFromJson(JsonObject json, String name) throws OXException {
+        return getIntFromJson(json, name, false);
+    }
+
     public static JsonArray getArrayFromJson(JsonObject json, String name) throws OXException {
         return getArrayFromJson(json,name,false);
     }
-    
+
     public static JsonArray getArrayFromJson(JsonObject json, String name, boolean madatory) throws OXException {
         if(!json.has(name)) {
             if(madatory) {
@@ -208,4 +210,23 @@ public final class JsonUtil {
             return "";
         }
     }
+
+    /**
+     * Maps an object to JSON and returns it as String
+     *
+     * @param object The object to map
+     * @return The mapped JSON as String
+     * @throws OXException
+     */
+    public static String toJsonString(Object object) throws OXException {
+        try {
+            return new ObjectMapper().writeValueAsString(object);
+        } catch (JsonProcessingException e) {
+            throw GuardCoreExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+        }
+    }
+
+    public static String emptyJsonString() throws OXException {
+        return "{}";
+    }
 }
