@@ -56,6 +56,15 @@ package com.openexchange.guard.configuration;
  */
 public enum GuardProperty {
 
+    /**
+     * Defines whether Guard accepts unsigned SRV records when performing HKP Server lookup via DNS.
+     * <br>
+     * <br>
+     * If false OX Guard will reject SRV Records which are not DNSSEC signed.
+     * <br>
+     * If true OX Guard logs a warning message when accepting non DNSSEC records.
+     */
+    allowUnsignedSRVRecords(true, GuardProperty.PREFIX + "dns."),
     /**
      * Defines the API user agent
      */
@@ -142,6 +151,21 @@ public enum GuardProperty {
      */
     externalReaderPath("example.com/guard/reader/reader.html"),
     externalReaderURL,
+    /**
+     * The directory used for buffering uploaded data.
+     * Default: empty which falls back to use "java.io.tmpdir"
+     */
+    fileUploadDirectory,
+    /**
+     * The threshold in bytes at which uploaded data will be buffered to disk.
+     * NOTE: Guard does only buffer non sensitive or encrypted data to disk.
+     * default: 10240 = 10 Kb
+     */
+    fileUploadBufferThreshhold(10240),
+    /**
+     * Defines if Guard should only establish secure TLS connections to HKP servers queried via DNS SVR lookup.
+     */
+    forceTLSForHKPSRV(false),
     fromEmail,
     /**
      * Specifies the SMTP server password.
@@ -199,7 +223,7 @@ public enum GuardProperty {
      * Specifies the password for the basic HTTP authentication used for accessing the mail resolver.
      * If no password is specified here, com.openexchange.guard.restApiPassword will be used as fallback (default)
      */
-    basicAuthPassword(GuardProperty.EMPTY,GuardProperty.PREFIX + "mailResolverUrl."),    
+    basicAuthPassword(GuardProperty.EMPTY,GuardProperty.PREFIX + "mailResolverUrl."),
     /**
      * Max number of connections to same URL (route)
      */
@@ -217,6 +241,11 @@ public enum GuardProperty {
      * password. (default=10)
      */
     newPassLength(10),
+    /**
+     * When creating a new Guest, option to send them a first password
+     * in a seperate email, or let them assign password on first login
+     */
+    newGuestsRequirePassword(false),
     /**
      * If the user should not be able to delete the private keys,
      * only retract, select true here
@@ -421,6 +450,11 @@ public enum GuardProperty {
      * Specifies the path for the templates
      */
     templatesDirectory("/opt/open-xchange/templates/guard"),
+    /**
+     * Defines how long temporary tokens should last before expiring.
+     * Time in hours
+     */
+    temporaryTokenLifespan(48),
     /**
      * Defines the version of the 'Upgrader'
      */
