@@ -51,6 +51,7 @@ package com.openexchange.guard.dns.internal;
 
 import java.util.ArrayList;
 import java.util.List;
+import org.xbill.DNS.Flags;
 import org.xbill.DNS.Lookup;
 import org.xbill.DNS.Record;
 import org.xbill.DNS.SRVRecord;
@@ -69,6 +70,24 @@ import com.openexchange.guard.dns.exception.DNSExceptionCodes;
  */
 public class DNSServiceImpl implements DNSService {
 
+    private final DNSValidator validator;
+
+    /**
+     * Initializes a new {@link DNSServiceImpl}.
+     */
+    public DNSServiceImpl() {
+        this(null);
+    }
+
+    /**
+     * Initializes a new {@link DNSServiceImpl}.
+     * 
+     * @param validator A validator used for validating DNSSEC signatures of records, or null to not validate records
+     */
+    public DNSServiceImpl(DNSValidator validator) {
+        this.validator = validator;
+    }
+
     /**
      * Get a list of SRV Records for PGP Servers for given domain
      *
@@ -84,7 +103,15 @@ public class DNSServiceImpl implements DNSService {
         }
         String domain = email.substring(email.indexOf("@") + 1);
         try {
-            Record[] records = new Lookup("_hkp._tcp." + domain, Type.SRV).run();
+            Lookup lookup = new Lookup("_hkp._tcp." + domain, Type.SRV);
+            if (validator != null) {
+                //Decorating the resolver with decorators which...
+                lookup.setResolver(
+                    new HeaderFlagResolverDecorator( //...adds the AD flag to each query
+                        new ValidatingResolverDecorator(Lookup.getDefaultResolver(), validator), //..validates each DNS response with the given validator
+                        Flags.AD));
+            }
+            Record[] records = lookup.run();
             if (records == null) {
                 return list;
             }
@@ -97,7 +124,7 @@ public class DNSServiceImpl implements DNSService {
         }
         return list;
     }
-    
+
     @Override
     public SRVRecord findNext(int current, List<SRVRecord> records) {
         int index = -1;
