@@ -50,7 +50,6 @@
 package com.openexchange.guard.keys.internal.pgp;
 
 import java.io.ByteArrayInputStream;
-import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -60,7 +59,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.TreeSet;
-import org.bouncycastle.bcpg.ArmoredOutputStream;
 import org.bouncycastle.bcpg.sig.RevocationReasonTags;
 import org.bouncycastle.openpgp.PGPEncryptedData;
 import org.bouncycastle.openpgp.PGPException;
@@ -88,18 +86,18 @@ import com.openexchange.guard.common.util.CipherUtil;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
-import com.openexchange.guard.keys.GuardKeyService;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.OGPGPKey;
+import com.openexchange.guard.keymanagement.commons.PGPKeys;
+import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
 import com.openexchange.guard.keys.dao.KeySignatureVerificationResult;
-import com.openexchange.guard.keys.dao.OGPGPKey;
-import com.openexchange.guard.keys.dao.PGPKeys;
 import com.openexchange.guard.keys.internal.pgp.exceptions.PGPKeyExceptionCodes;
 import com.openexchange.guard.keys.osgi.Services;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
-import com.openexchange.guard.keys.storage.OGPGPKeysStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
-import com.openexchange.guard.keys.util.PGPUtil;
 
 /**
  * {@link PGPKeyServiceImpl}
@@ -119,7 +117,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#updatePGPKeys(int, int, com.openexchange.guard.keys.dao.GuardKeys)
      */
     @Override
@@ -127,12 +125,12 @@ public class PGPKeyServiceImpl implements PGPKeyService {
         KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
         ogKeyTableStorage.updatePublicAndPrivateKey(key);
         PGPKeysStorage keysStorage = Services.getService(PGPKeysStorage.class);
-        keysStorage.addPublicKeyIndex(key.getContextid(), 0L, key.getEmail(), key.getPublicKeyRing());
+        keysStorage.addPublicKeyIndex(key.getContextid(), 0L, key.getEmail(), key.getPGPPublicKeyRing());
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#getPublicKeyRingById(long, int, int)
      */
     @Override
@@ -143,8 +141,8 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             if (keyMapping != null) {
                 if (keyMapping.isLocal()) {
                     GuardKeyService keyService = Services.getService(GuardKeyService.class);
-                    GuardKeys key = keyService.getKeysFromEmail(keyMapping.getEmail(), keyMapping.getKeyId());
-                    return key.getPublicKeyRing();
+                    GuardKeys key = keyService.getKeys(keyMapping.getEmail(), keyMapping.getKeyId());
+                    return key.getPGPPublicKeyRing();
                 }
             }
 
@@ -158,7 +156,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#getPublicKeyRingById(java.lang.String, int, int)
      */
     @Override
@@ -169,8 +167,8 @@ public class PGPKeyServiceImpl implements PGPKeyService {
             if (keyMapping != null) {
                 if (keyMapping.isLocal()) {
                     GuardKeyService keyService = Services.getService(GuardKeyService.class);
-                    GuardKeys key = keyService.getKeysFromEmail(keyMapping.getEmail(), keyMapping.getKeyId());
-                    return key.getPublicKeyRing();
+                    GuardKeys key = keyService.getKeys(keyMapping.getEmail(), keyMapping.getKeyId());
+                    return key.getPGPPublicKeyRing();
                 }
             }
             return (getUploadedPublicKeyRingById(hexId, userid, cid));
@@ -183,7 +181,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#getPublicKeyRing(java.lang.String)
      */
     @Override
@@ -209,9 +207,9 @@ public class PGPKeyServiceImpl implements PGPKeyService {
         List<PGPPublicKeyRing> ret = new ArrayList<PGPPublicKeyRing>();
         for (PGPKeys internalMapping : internalKeyMappings) {
             if (internalMapping.isLocal()) {
-                GuardKeys key = keyService.getKeysFromEmail(email,internalMapping.getKeyId());
+                GuardKeys key = keyService.getKeys(email,internalMapping.getKeyId());
                 if (key != null) {
-                    ret.add(key.getPublicKeyRing());
+                    ret.add(key.getPGPPublicKeyRing());
                 }
             }
         }
@@ -220,47 +218,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
-     * @see com.openexchange.guard.keys.PGPKeyService#updateDuplicatePGPKey(int, int, com.openexchange.guard.keys.dao.GuardKeys, java.lang.String, java.lang.Long)
-     */
-    @Override
-    public void updateDuplicatePGPKey(int id, int cid, GuardKeys key, String recovery, Long duplicate) throws OXException {
-        KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
-        ogKeyTableStorage.updateDuplicate(key, recovery, duplicate);
-    }
-
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.guard.keys.PGPKeyService#export(org.bouncycastle.openpgp.PGPPublicKeyRing)
-     */
-    @Override
-    public String export(PGPPublicKeyRing pgpKeyRing) throws OXException {
-        try {
-            ByteArrayOutputStream out = new ByteArrayOutputStream();
-            ArmoredOutputStream arm = new ArmoredOutputStream(out);
-            ByteArrayOutputStream bout = new ByteArrayOutputStream();
-
-            Iterator<PGPPublicKey> keys = pgpKeyRing.getPublicKeys();
-            while (keys.hasNext()) {
-                PGPPublicKey k = keys.next();
-                k.encode(bout);
-            }
-            arm.write(bout.toByteArray());
-
-            arm.close();
-            bout.close();
-            out.close();
-
-            return (new String(out.toByteArray()));
-        } catch (IOException e) {
-            throw PGPKeyExceptionCodes.IO_ERROR.create(e, e.getMessage());
-        }
-    }
-
-    /*
-     * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#getPGPPrivateKey(java.lang.String, java.lang.String, org.bouncycastle.openpgp.PGPSecretKeyRing)
      */
     @Override
@@ -285,23 +243,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
-     * @see com.openexchange.guard.keys.PGPKeyService#getPGPPrivateKey(java.lang.String, java.lang.String, org.bouncycastle.openpgp.PGPSecretKeyRing, long)
-     */
-    @Override
-    public PGPPrivateKey getPGPPrivateKey(String password, String salt, PGPSecretKeyRing keyRing, long id) throws OXException {
-        PGPSecretKey secretKey = keyRing.getSecretKey(id);
-        if (secretKey != null) {
-            return getDecodedPrivate(secretKey, password, salt);
-        } else {
-            LOG.error("Unable to find PGP key for id {}", Long.toString(id));
-            return null;
-        }
-    }
-
-    /*
-     * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#getPGPSignKey(org.bouncycastle.openpgp.PGPSecretKeyRing, java.lang.String, java.lang.String)
      */
     @Override
@@ -315,7 +257,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#checkSignatures(int, int, org.bouncycastle.openpgp.PGPPublicKeyRing)
      */
     @Override
@@ -331,7 +273,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#checkSignatures(int, int, org.bouncycastle.openpgp.PGPPublicKey)
      */
     @SuppressWarnings("unchecked")
@@ -348,22 +290,13 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#addUID(org.bouncycastle.openpgp.PGPPrivateKey, org.bouncycastle.openpgp.PGPPublicKeyRing, java.lang.String)
      */
     @Override
     public PGPPublicKeyRing addUID(PGPPrivateKey privateKey, PGPPublicKeyRing publicKeyRing, String userId) throws OXException {
         try {
-            PGPPublicKey pub = publicKeyRing.getPublicKey();
-            PGPSignatureGenerator generator = new PGPSignatureGenerator(new BcPGPContentSignerBuilder(PGPPublicKey.RSA_GENERAL, org.bouncycastle.openpgp.PGPUtil.SHA1));
-            generator.init(PGPSignature.POSITIVE_CERTIFICATION, privateKey);
-            PGPSignatureSubpacketGenerator signhashgen = new PGPSignatureSubpacketGenerator();
-            generator.setHashedSubpackets(signhashgen.generate());
-            PGPSignature certification = generator.generateCertification(userId, pub);
-            PGPPublicKey newPubKey = PGPPublicKey.addCertification(pub, userId, certification);
-            publicKeyRing = PGPPublicKeyRing.removePublicKey(publicKeyRing, pub);
-            publicKeyRing = PGPPublicKeyRing.insertPublicKey(publicKeyRing, newPubKey);
-            return publicKeyRing;
+            return PGPUtil.addUID(publicKeyRing, privateKey, userId);
         } catch (PGPException e) {
             throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
         }
@@ -371,13 +304,13 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#checkBadUID(com.openexchange.guard.keys.dao.GuardKeys, java.lang.String)
      */
     @SuppressWarnings("unchecked")
     @Override
     public void checkBadUID(GuardKeys keys, String password) throws OXException {
-        PGPPublicKey pubkey = keys.getPublicKeyRing().getPublicKey();
+        PGPPublicKey pubkey = keys.getPGPPublicKeyRing().getPublicKey();
         Iterator<String> it = pubkey.getUserIDs();
         while (it.hasNext()) {
             String uid = it.next();
@@ -398,7 +331,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                     throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
                 }
                 if (priv != null) {
-                    keys.setPublicKeyRing(addUID(priv, keys.getPublicKeyRing(), newuid));
+                    keys.setPGPPublicKeyRing(addUID(priv, keys.getPGPPublicKeyRing(), newuid));
                     PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
                     pgpKeyService.updatePGPKeys(keys.getUserid(), keys.getContextid(), keys);
                     markUIDUpdated(keys);
@@ -410,7 +343,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#createPublicKeyRingFromPrivateKey(org.bouncycastle.openpgp.PGPSecretKeyRing)
      */
     @Override
@@ -438,18 +371,18 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#revokePGPPublicKeys(com.openexchange.guard.keys.dao.GuardKeys, java.lang.String, java.lang.String)
      */
     @Override
     public GuardKeys revokePGPPublicKeys(GuardKeys keys, String password, String reason) throws OXException {
         try {
             PGPSecretKey secretKey = keys.getPGPSecretKey();
-            Iterator<PGPPublicKey> pkeys = keys.getPublicKeyRing().getPublicKeys();
+            Iterator<PGPPublicKey> pkeys = keys.getPGPPublicKeyRing().getPublicKeys();
             PGPPublicKey master = secretKey.getPublicKey();
             while (pkeys.hasNext()) {
                 PGPPublicKey pub = pkeys.next();
-                keys.setPublicKeyRing(PGPPublicKeyRing.removePublicKey(keys.getPublicKeyRing(), pub));
+                keys.setPGPPublicKeyRing(PGPPublicKeyRing.removePublicKey(keys.getPGPPublicKeyRing(), pub));
                 PGPSignatureSubpacketGenerator subHashGenerator = new PGPSignatureSubpacketGenerator();
                 PGPSignatureSubpacketGenerator subUnHashGenerator = new PGPSignatureSubpacketGenerator();
                 PGPSignatureGenerator generator = new PGPSignatureGenerator(new BcPGPContentSignerBuilder(pub.getAlgorithm(), org.bouncycastle.openpgp.PGPUtil.SHA1));
@@ -473,7 +406,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
                     pub = PGPPublicKey.addCertification(pub, signature);
                 }
 
-                keys.setPublicKeyRing(PGPPublicKeyRing.insertPublicKey(keys.getPublicKeyRing(), pub));
+                keys.setPGPPublicKeyRing(PGPPublicKeyRing.insertPublicKey(keys.getPGPPublicKeyRing(), pub));
             }
 
             return keys;
@@ -484,7 +417,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#signPGPPublicKey(org.bouncycastle.openpgp.PGPPublicKey, com.openexchange.guard.keys.dao.GuardKeys, java.lang.String)
      */
     @Override
@@ -504,7 +437,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#signPGPPublicKeyRing(org.bouncycastle.openpgp.PGPSecretKey, org.bouncycastle.openpgp.PGPPrivateKey, org.bouncycastle.openpgp.PGPPublicKey)
      */
     @Override
@@ -525,32 +458,6 @@ public class PGPKeyServiceImpl implements PGPKeyService {
         }
     }
 
-    /*
-     * (non-Javadoc)
-     * 
-     * @see com.openexchange.guard.keys.PGPKeyService#exportPGPPrivateKey(com.openexchange.guard.keys.dao.GuardKeys, java.lang.String)
-     */
-    @Override
-    public String exportPGPPrivateKey(GuardKeys keys, String password) throws OXException {
-        try {
-            String oldpass = CipherUtil.getSHA(password, keys.getSalt());
-            PGPSecretKeyRing newkeyring = PGPUtil.duplicateSecretKeyRing(keys.getPGPSecretKeyRing(), oldpass, password, getPGPEncryptedData());
-            if (newkeyring == null) {
-                throw PGPKeyExceptionCodes.PGP_ERROR.create("Bad password");
-            }
-            ByteArrayOutputStream out = new ByteArrayOutputStream();
-            ArmoredOutputStream arm = new ArmoredOutputStream(out);
-            arm.write(newkeyring.getEncoded());
-            arm.close();
-            out.close();
-            return (new String(out.toByteArray()));
-        } catch (PGPException e) {
-            throw PGPKeyExceptionCodes.PGP_ERROR.create(e, e.getMessage());
-        } catch (IOException e) {
-            throw PGPKeyExceptionCodes.IO_ERROR.create(e, e.getMessage());
-        }
-    }
-
     ////////////////////////////////// HELPERS /////////////////////////////////////////
 
     /**
@@ -571,7 +478,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
         if (pgpKeys.size() > 0) {
             GuardKeys key = new GuardKeys();
             key.setPGPKeyRingFromAsc(pgpKeys.get(0).getPublicPGPAscData());
-            return key.getPublicKeyRing();
+            return key.getPGPPublicKeyRing();
         }
         return null;
     }
@@ -749,7 +656,7 @@ public class PGPKeyServiceImpl implements PGPKeyService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.keys.PGPKeyService#importPGPPrivateKey(com.openexchange.guard.keys.dao.GuardKeys, java.lang.String, java.lang.String, java.lang.String)
      */
     @Override
