@@ -103,10 +103,19 @@ public class MailCreatorServiceImpl implements MailCreatorService {
     }
 
     @Override
-    public JsonObject createBlankGuestMail(String lang, int templId, String host, int userid, int cid) throws OXException {
+    public JsonObject createBlankGuestMail(String lang, int templId, String host, int userid, int cid, String guestMessage) throws OXException {
+        return createBlankMail (lang, templId, host, userid, cid, "guesttempl.html", guestMessage);
+    }
+
+    @Override
+    public JsonObject createBlankMail (String lang, int templId, String host, int userid, int cid, String template, String guestmessage) throws OXException {
         JsonObject email = createBlankMail();
+        ArrayList<TemplateTransformation> transformations = new ArrayList<TemplateTransformation>();
+        //"guestmessage" is a conditional part of the template file. We only show it, if the user entered a guest message
+        transformations.add(new ConditionalVissibleTemplateTransformation("guestmessage", guestmessage == null || guestmessage.isEmpty()));
+        transformations.add(new ConditionalVissibleTemplateTransformation("!guestmessage", guestmessage != null && !guestmessage.isEmpty()));
         GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
-        String content = translationService.getTranslation("guesttempl.html", lang, templId);
+        String content = translationService.getTranslation(template, lang, templId, transformations);
         content = setProductName (content, host, userid, cid);
         if (content == null) {
             return (null);
@@ -115,8 +124,8 @@ public class MailCreatorServiceImpl implements MailCreatorService {
     }
 
     @Override
-    public JsonObject createBlankGuestMail(String lang, int templId, String messageID, String host, int userid, int cid) throws OXException {
-        JsonObject mail = createBlankGuestMail(lang, templId, host, userid, cid);
+    public JsonObject createBlankGuestMail(String lang, int templId, String messageID, String host, int userid, int cid, String guestMessage) throws OXException {
+        JsonObject mail = createBlankGuestMail(lang, templId, host, userid, cid, guestMessage);
         JsonObject header = new JsonObject();
         header.addProperty("Message-ID", messageID);
         mail.get("data").getAsJsonObject().add("headers", header);
@@ -130,7 +139,7 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         if (data == null) {
             data = "";
         }
-        emailText = emailText.replace("$plaintext", data);
+        emailText = emailText.replace("$plaintext", data.replace("\r", "<br>"));
         Gson g = new Gson();
         return (g.fromJson(emailText, JsonObject.class));
     }
@@ -245,6 +254,23 @@ public class MailCreatorServiceImpl implements MailCreatorService {
         return getPasswordEmail(to, sendername, from, from2, password, lang, templId, guestmessage, "passwordtempl.html", host, userid, cid);
     }
 
+    /**
+     *
+     * @param to email of recipient
+     * @param sendername Full name of the sender
+     * @param from  Full name of the sender
+     * @param from2 Email of the sender
+     * @param password password to send
+     * @param lang
+     * @param templId
+     * @param guestmessage
+     * @param templateName
+     * @param host the senders hostname
+     * @param userid the recipient's user id
+     * @param cid the recipient's context id
+     * @return
+     * @throws OXException
+     */
     private JsonObject getPasswordEmail(String to, String sendername, String from, String from2, String password, String lang, int templId, String guestmessage, String templateName, String host, int userid, int cid) throws OXException {
         JsonObject email = createBlankMail();
         email = addTo(email, to, to);
@@ -279,12 +305,24 @@ public class MailCreatorServiceImpl implements MailCreatorService {
 
     @Override
     public JsonObject getResetEmail(String to, List<String> from, String password, String lang, int templId, String host, int userid, int cid) throws OXException {
+        GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
+        String templ = translationService.getTranslation("resettempl.html", lang, templId).replace("$from", from.get(0)).replace("$password", password);
+        return (templToEmail (templ, to, from, host, userid, cid));
+    }
+
+    @Override
+    public JsonObject getGuestResetEmail(String to, String resetId, String lang, int templId, String host, int userid, int cid) throws OXException {
+        List<String> from = getFromAddress(to, to, userid, cid);
+        GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
+        String templ = translationService.getTranslation("guestresettempl.html", lang, templId).replace("$resetid", resetId);
+        return (templToEmail (templ, to, from, host, userid, cid));
+    }
+
+    private JsonObject templToEmail (String templ, String to, List<String> from, String host, int userid, int cid) throws OXException {
         JsonObject email = createBlankMail();
         email = addTo(email, to, to);
         email = addFrom(email, from.get(0), from.get(1));
         email.getAsJsonObject("data").add("copy2Sent", new JsonPrimitive("false"));// Do not copy this to sent folder
-        GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
-        String templ = translationService.getTranslation("resettempl.html", lang, templId).replace("$from", from.get(0)).replace("$password", password);
         templ = setProductName (templ, host, userid, cid);
         if (templ.contains("Subject:")) {
             String subject = templ.substring(templ.indexOf("Subject:"), templ.indexOf("\n", templ.indexOf("Subject:"))).replace("Subject:", "");
@@ -367,8 +405,8 @@ public class MailCreatorServiceImpl implements MailCreatorService {
      * @throws OXException
      */
     public String setProductName (String content, String host, int id, int cid) throws OXException {
-    	String name = GuardProductName.getProductName(host, cid, id);
-    	content = content.replace("$productName", name);
-    	return (content);
+        String name = GuardProductName.getProductName(host, cid, id);
+        content = content.replace("$productName", name);
+        return (content);
     }
 }
