@@ -51,6 +51,7 @@ package com.openexchange.guard.management.maintenance;
 
 import java.rmi.RemoteException;
 import javax.management.MBeanException;
+import com.openexchange.guard.management.maintenance.internal.TestUserResult;
 
 /**
  * {@link GuardMaintenanceMBean}
@@ -99,6 +100,14 @@ public interface GuardMaintenanceMBean {
      */
     String test(String email) throws MBeanException;
 
+    /**
+     * Perform a simple test for the provided e-mail address
+     *
+     * @param email The e-mail address of the user
+     * @throws RemoteException
+     */
+    TestUserResult testUser(String email) throws MBeanException;
+
     /**
      * Deletes a user from Guard
      * @param email
@@ -106,4 +115,12 @@ public interface GuardMaintenanceMBean {
      */
     void deleteUser(String email) throws MBeanException;
 
+    /**
+     * Resets a Guest account with new Keys
+     * @param email
+     * @param force
+     * @throws MBeanException
+     */
+    void resetGuest(String email, boolean force) throws MBeanException;
+
 }
