@@ -105,7 +105,13 @@ public class GuardNotificationServiceImpl implements GuardNotificationService {
 
     @Override
     public void send(final JsonObject email) throws OXException {
-        send(email, null);
+        final GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
+        send(email, null, "", guardConfigService.getProperty(GuardProperty.defaultLanguage), getMessageID());
+    }
+
+    @Override
+    public void send(final JsonObject email, String lang) throws OXException {
+        send (email, null, "", lang, getMessageID());
     }
 
     @Override
