@@ -793,7 +793,7 @@ public class Api {
         final Pattern pattern = Pattern.compile(filenameRegex, Pattern.DOTALL);
         HttpResponse response = null;
         try {
-            url = java.net.URLDecoder.decode(url, "UTF-8").replace("&amp;", "&");
+            url = url.replace("&amp;", "&");  // Maintain url encoding except for the &  Bug 47911
             if (url.contains("file?action") || url.contains("image/mail") || url.contains("image/snippet")) {
                 int index = 0;
                 if (url.contains("file?action")) {
