@@ -58,12 +58,13 @@ import org.bouncycastle.openpgp.PGPSecretKey;
 import org.slf4j.Logger;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.CipherUtil;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 import com.openexchange.guard.pgpcore.commons.PGPDecrypter;
 import com.openexchange.guard.pgpcore.commons.PGPEncrypter;
 import com.openexchange.guard.pgpcore.commons.PGPKeyRetrievalStrategy;
 import com.openexchange.guard.pgpcore.commons.PGPSignatureVerificationResult;
+import com.openexchange.guard.pgpcore.commons.GuardKeyRingRetrievalStrategy;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
 import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExceptionCodes;
@@ -76,32 +77,42 @@ import com.openexchange.guard.pgpcore.services.exceptions.PGPCoreServicesExcepti
  */
 public class PGPCryptoServiceImpl implements PGPCryptoService {
 
-    private final GuardKeyService guardKeyService;
     private final PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy;
+    private final GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy;
     private static final Logger logger = org.slf4j.LoggerFactory.getLogger(PGPCryptoServiceImpl.class);
 
     /**
      * Initializes a new {@link PGPCryptoServiceImpl}.
+     *
+     * @param pgpKeyRetrievalStrategy the strategy for retrieving keys for decryption.
+     * @param recipientKeyRingRetrievalStrategy the strategy for retrieving keys for encryption
      */
-    public PGPCryptoServiceImpl(GuardKeyService guardKeyService, PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy) {
-        this.guardKeyService = guardKeyService;
+    public PGPCryptoServiceImpl(GuardKeyRingRetrievalStrategy recipientKeyRingRetrievalStrategy,
+                                PGPKeyRetrievalStrategy pgpKeyRetrievalStrategy) {
+        this.recipientKeyRingRetrievalStrategy = recipientKeyRingRetrievalStrategy;
         this.pgpKeyRetrievalStrategy = pgpKeyRetrievalStrategy;
     }
 
     /**
      * Fetches the public keys for the given identities
-     * 
+     *
      * @param recipients The identities to fetch the public keys for
      * @return A set of public keys for the given identities
      * @throws OXException If a key was not found for a given identity
      */
     PGPPublicKey[] getRecipientKeys(List<String> recipients) throws OXException {
-        ArrayList<PGPPublicKey> ret = new ArrayList<PGPPublicKey>();
+
+        ArrayList<PGPPublicKey> ret = new ArrayList<>();
         for (String recipient : recipients) {
-            //By now we assume that the recipients list contains emails
-            GuardKeys keysforEmail = guardKeyService.getKeysFromEmail(recipient);
-            if (keysforEmail != null) {
-                ret.add(keysforEmail.getPGPPublicKey());
+            GuardKeys guardKeys = recipientKeyRingRetrievalStrategy.getKeyRingForRecipient(recipient);
+            if(guardKeys != null) {
+                PGPPublicKey key = guardKeys.getPGPPublicKey();
+                if (key != null) {
+                    ret.add(key);
+                }
+                else {
+                    throw PGPCoreServicesExceptionCodes.RECIPIENT_KEY_NOT_FOUND.create(recipient);
+                }
             }
             else {
                 throw PGPCoreServicesExceptionCodes.RECIPIENT_KEY_NOT_FOUND.create(recipient);
@@ -112,13 +123,13 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
 
     /**
      * Fetches the Guard key for the given identity
-     * 
+     *
      * @param identity The identity to get the signing key for
      * @return The signing key for the given identity
      * @throws OXException If the key was not found
      */
     GuardKeys getSignerGuardKey(String identity) throws OXException {
-        GuardKeys guardKeys = guardKeyService.getKeysFromEmail(identity);
+        GuardKeys guardKeys = recipientKeyRingRetrievalStrategy.getKeyRingForRecipient(identity);
         if (guardKeys != null) {
             return guardKeys;
         }
@@ -129,13 +140,13 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
 
     /**
      * Extracts the PGP signing key from the given Guard key
-     * 
+     *
      * @param guardKey The key to get the singing key for
      * @return The signing key for the given Guard key
      * @throws OXException If no signing key was found
      */
     PGPSecretKey getSignerKey(GuardKeys guardKey) throws OXException {
-        PGPSecretKey signingKey = com.openexchange.guard.keys.util.PGPUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
+        PGPSecretKey signingKey = PGPUtil.getSigningKey(guardKey.getPGPSecretKeyRing());
         if (signingKey != null) {
             return signingKey;
         }
@@ -143,14 +154,14 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
             throw PGPCoreServicesExceptionCodes.SIGNING_KEY_NOT_FOUND.create(guardKey.getKeyid());
         }
     }
-    
+
     private String listToString(List l) {
         return l.toString().replace("[", "").replace("]", "").replace(", ", ",");
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#encrypt(java.io.InputStream, java.io.OutputStream, boolean, com.openexchange.guard.pgpcore.services.PGPPublicKey[])
      */
     @Override
@@ -162,13 +173,13 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
         } catch (OXException e) {
             throw e;
         } catch (Exception e) {
-            PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
+            throw PGPCoreServicesExceptionCodes.ENCRYPTION_ERROR.create(e, e.getMessage());
         }
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#encryptSigned(java.io.InputStream, java.io.OutputStream, boolean, com.openexchange.guard.pgpcore.services.PGPSecretKey, char[],
      * com.openexchange.guard.pgpcore.services.PGPPublicKey[])
      */
@@ -190,7 +201,7 @@ public class PGPCryptoServiceImpl implements PGPCryptoService {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.pgpcore.services.PGPCryptoService#decrypt(java.io.InputStream, java.io.OutputStream, java.lang.String, char[])
      */
     @Override
