@@ -61,7 +61,7 @@ import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.handler.exceptions.GuardResponseHandlerExceptionCodes;
-import com.openexchange.guard.keys.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 
 /**
  * {@link ResponseHandlerImpl}
