@@ -54,12 +54,14 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.GuardMaintenanceService;
+import com.openexchange.guard.UserTestResult;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.guestreset.GuestResetService;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
@@ -129,10 +131,9 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
     private void resetPass(String email) throws Exception {
         try {
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
-            GuardKeys keys = keyService.getKeysFromEmail(email);
+            GuardKeys keys = keyService.getKeys(email);
             if (keys == null) {
-                System.out.println("NO ACCOUNT FOUND");
-                return;
+                throw GuardMaintenanceExceptionCodes.UNABLE_TO_RESOLVE_MAIL_ADDRESS.create(email);
             }
             if (keys.getContextid() < 0) {// Guest
                 int templid = 0;
@@ -210,4 +211,11 @@ public class GuardMaintenanceServiceImpl implements GuardMaintenanceService {
         	SupportService svc = new SupportServiceImpl();
         	svc.deleteUser(email);
     }
+
+    @Override
+    public void resetGuest(String email, boolean force) throws OXException {
+        GuestResetService resetService = Services.getService(GuestResetService.class);
+        resetService.reset(email, 0, "", force, null);
+    }
+
 }
