@@ -57,27 +57,26 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
-import com.openexchange.exception.OXException;
-import com.openexchange.guard.bad.GuardBadStorage;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
-import com.openexchange.guard.configuration.GuardConfigurationService;
-import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.handler.ResponseHandler;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
+import com.openexchange.guard.user.GuardCapabilities;
 
 public class GuardSettings {
 
-    private static Logger LOG = LoggerFactory.getLogger(Settings.class);
+    private static Logger LOG = LoggerFactory.getLogger(GuardCapabilities.class);
 
     public void setSettings(HttpServletRequest request, HttpServletResponse response, OxCookie cookie, int userId, int cid) throws Exception {
         JsonObject data = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
         Api ap = new Api(cookie, request);
         // Must either be logged in or sent with authorization code
+        GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         if (!ap.verifyLogin()) {
             String auth = ServletUtils.getStringParameter(request, "auth", true);
             if (auth.length() > 20) {
@@ -85,8 +84,7 @@ public class GuardSettings {
                 UserData user = new UserData(auth, cookie);
                 if ((user.getUserid() == -1) || (user.getEncr_password() == null)) {
                     ServletUtils.sendNotAcceptable(response, "Bad authorization");
-                    GuardBadStorage badStorage = Services.getService(GuardBadStorage.class);
-                    badStorage.addBad(cookie.getJSESSIONID());
+                    antiabuse.addBad(cookie.getJSESSIONID());
                     ServletUtils.sendNotAcceptable(response, "Must be logged in");
                     return;
                 }
@@ -95,6 +93,10 @@ public class GuardSettings {
                 return;
             }
         }
+        if (antiabuse.isBad(cookie.getJSESSIONID())) {
+        	ServletUtils.sendNotAcceptable(response, "Lockout");
+        	return;
+        }
         JsonObject current = getCurrentSettings(userId, cid);
         JsonElement dataParam = data.get("data");
         if (dataParam == null) {
@@ -136,16 +138,4 @@ public class GuardSettings {
         }
         return true;
     }
-
-    //TODO: moved here temporarily
-    public static boolean checkCreateRecovery(OxCookie cookie, HttpServletRequest request) throws OXException {
-    	GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        if (configService.getBooleanProperty(GuardProperty.noRecovery)) {
-            // If global no Recovery then return false.
-            return false;
-        }
-        // get individual settings
-        Settings settings = new Auth().getPermissions(cookie, request);
-        return (!settings.isNorecovery());
-    }
 }
