@@ -86,7 +86,7 @@ public class UserData {
             if (token == null) {
                 return;
             }
-            GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES);
+            GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_GCM);
             String userdata = cipherService.decrypt(auth, token);
             if (userdata.equals("")) {
                 return;// Bad authentication
