@@ -93,16 +93,14 @@ import com.openexchange.guard.encryption.EncryptedItem;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.guest.GuestInlineImageHandler;
-import com.openexchange.guard.internal.Auth;
-import com.openexchange.guard.internal.Settings;
-import com.openexchange.guard.internal.Settings.permissions;
 import com.openexchange.guard.internal.UserData;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.GuardMasterKeyService;
-import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.PublicKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.RecipKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
+import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.RecipKeyService;
 import com.openexchange.guard.mail.exceptions.OXMailExceptionCodes;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.osgi.Services;
@@ -122,6 +120,9 @@ import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImp
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.ratifier.GuardRatifierService;
+import com.openexchange.guard.user.GuardCapabilities;
+import com.openexchange.guard.user.GuardUserService;
+import com.openexchange.guard.user.GuardCapabilities.Permissions;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 
@@ -164,6 +165,9 @@ public class Incoming {
                 String maxSizeProperty = configurationService.getPropertyFromFile("server.properties", "MAX_UPLOAD_SIZE");
                 if (maxSizeProperty != null) {
                     maxSize = Long.parseLong(maxSizeProperty);
+                    if (maxSize ==0) {
+                        maxSize = -1L;
+                    }
                 }
                 else {
                     maxSize = -1L;
@@ -186,6 +190,9 @@ public class Incoming {
         long maxSize = -1L;
         if (maxSizeProperty != null) {
             maxSize = Long.parseLong(maxSizeProperty);
+            if(maxSize == 0) {
+                maxSize = -1L;
+            }
         }
         return createServletFileUpload(maxSize, maxSize);
     }
@@ -230,7 +237,10 @@ public class Incoming {
         String draftFolder = ServletUtils.getStringParameter(request, "draftfolder");
         String pin = null;
         boolean draft = ServletUtils.getBooleanParameter(request, "draft", false);
-        int templId = ServletUtils.getIntParameter(request, "templid");
+        Integer templId = ServletUtils.getIntParameter(request, "templid");
+        if(templId == null) {
+            templId = 0;
+        }
         if (language == null) {
             language = "en-US";
         }
@@ -266,11 +276,12 @@ public class Incoming {
         boolean sendPermission = false;
         // Check for permission for sending email
         if (guest == null) {
-            Settings settings = new Auth().getPermissions(cookie, request);
-            if (!Auth.check(settings, permissions.MAIL)) {
+
+            GuardCapabilities guardUserCapabilities = Services.getService(GuardUserService.class).getGuardCapabilieties(cid, userid);
+            if (!guardUserCapabilities.hasPermission(Permissions.MAIL)) {
                 // If not permission, check if secure reply
                 if (sr == null) {
-                    if (Auth.checkMinimum(settings)) {  // Make sure they have minimal Guard permission
+                    if (guardUserCapabilities.hasMinimumPermission()) {  // Make sure they have minimal Guard permission
                         // Assuming secure reply from user without guard-mail settings
                         // ToDo in future...rate limit, recip limit, other
                         sendPermission = true;
@@ -388,7 +399,7 @@ public class Incoming {
 
             // If password wasn't sent, check if in auth
             if (attach_password == null && auth != null && !auth.isEmpty()) {
-            	UserIdentity id = getIdentityForToken(cookie.getJSESSIONID(), auth);
+                UserIdentity id = getIdentityForToken(cookie.getJSESSIONID(), auth);
                 if (id != null) {
                     attach_password = new String(id.getPassword());
                 }
@@ -397,9 +408,9 @@ public class Incoming {
             JsonObject data = json.getAsJsonObject("data");
             JsonArray from;
             try {
-            	from = data.get("from").getAsJsonArray().get(0).getAsJsonArray();
+                from = data.get("from").getAsJsonArray().get(0).getAsJsonArray();
             } catch (java.lang.NullPointerException ex) {
-            	throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("From Address Array");
+                throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("From Address Array");
             }
             if (!PGPUserIdChecker.checkHasUID(userid, cid, from.get(1).getAsString().trim())) {
                 LOG.info("From email not contained in sender key");
@@ -415,17 +426,19 @@ public class Incoming {
                 //Checking for new guest accounts
                 Api apiAccess = new Api(new OxCookie(request.getCookies()), request);
                 for (RecipKey recipient : recipients) {
-                    if (recipient.isGuest() && recipient.getNewGuestPass() != null && !recipient.getNewGuestPass().isEmpty()) {
-                        //Sending a welcome/password email to new guests
-                        try {
+                    if (guardConfigService.getBooleanProperty(GuardProperty.newGuestsRequirePassword)) {  // If Guests get new password email, send now
+                        if (recipient.isGuest() && recipient.getNewGuestPass() != null && !recipient.getNewGuestPass().isEmpty()) {
+                            //Sending a welcome/password email to new guests
+                            try {
 
-                            String fromName = from.get(0) != JsonNull.INSTANCE ? from.get(0).getAsString().trim() : null;
-                            String fromEmail = from.get(1).getAsString().trim();
-                            sendInitialGuestPasswordMail(apiAccess, fromName, fromEmail, recipient, templId, guestmessage, request.getServerName(), recipient.getUserid(), recipient.getCid());
-                        } catch (OXException e) {
-                            LOG.error("", e);
-                            ServletUtils.sendNotAcceptable(response, e.getDisplayMessage(new Locale(language)));
-                            return;
+                                String fromName = from.get(0) != JsonNull.INSTANCE ? from.get(0).getAsString().trim() : null;
+                                String fromEmail = from.get(1).getAsString().trim();
+                                sendInitialGuestPasswordMail(apiAccess, fromName, fromEmail, recipient, templId, guestmessage, request.getServerName(), recipient.getUserid(), recipient.getCid());
+                            } catch (OXException e) {
+                                LOG.error("", e);
+                                ServletUtils.sendNotAcceptable(response, e.getDisplayMessage(new Locale(language)));
+                                return;
+                            }
                         }
                     }
                 }
@@ -503,8 +516,7 @@ public class Incoming {
                     GuardKeyService keyService = Services.getService(GuardKeyService.class);
                     GuardKeys senderKeys = keyService.getKeys(userid, cid);
 
-                    PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
-                    addPublicKey(attachments, pgpKeyService.export(senderKeys.getPublicKeyRing()));
+                    addPublicKey(attachments, KeyExportUtil.export(senderKeys.getPGPPublicKeyRing()));
                     break;
                 }
             }
@@ -523,14 +535,14 @@ public class Incoming {
                 String reply = new PGPSender().sendPGPMail(mail, request.getServerName());
                 if (reply != null)
                 {
-                	if (JsonUtil.isJson(reply)) { // The reply will be either "OK" "Fail" or JSON Information
-                		ServletUtils.sendOK(response, "application/json", reply);  // If JSON string returned, then return it
-                	} else {
+                    if (JsonUtil.isJson(reply)) { // The reply will be either "OK" "Fail" or JSON Information
+                        ServletUtils.sendOK(response, "application/json", reply);  // If JSON string returned, then return it
+                    } else {
                         ServletUtils.sendOK(response, "text/html", reply);
                     }
                 }
             } catch (OXException e) {
-            	LOG.error("Problem sending email ", e);
+                LOG.error("Problem sending email ", e);
                 ServletUtils.sendNotAcceptable(response, e.getDisplayMessage(new Locale(language)));
             }
 
@@ -594,8 +606,20 @@ public class Incoming {
             InternetAddress emailAddress = new InternetAddress(IDNUtil.aceEmail(emailString));
             String email = IDNUtil.decodeEmail(emailAddress.getAddress());
 
-            PublicKeyService publicKeyService = Services.getService(PublicKeyService.class);
-            RecipKey key = publicKeyService.getPubKey(email, senderId, senderCID, from, !draft, false, guestlanguage, fromName, pin, info == null ? 0 : info.getOwnerId(), info == null ? 0 : info.getOwnerCid(), host);
+            //Lookup recipient key
+            RecipKey key = Services.getService(RecipKeyService.class).getRecipKey(senderId, senderCID, email);
+
+            //create key for recipient if this is not a draft
+            if (key != null &&  key.isNewKey() && !draft) {
+                key = Services.getService(AccountCreationService.class).createUserFor(key);
+                if (key.isGuest()) {
+                    key.setLang(guestlanguage);
+                    if (pin != null && !pin.isEmpty()) {
+                        Services.getService(GuardKeyService.class).updatePin(key.getUserid(), key.getCid(), pin);
+                    }
+                }
+            }
+
             if (key != null) {
                 if (key.getPubkey() == null) {
                     // Fail to create key
@@ -808,7 +832,7 @@ public class Incoming {
                         boolean found = false;
                         // First, search through our already loaded attachments and make sure wasn't sent with post
                         for (Attachment att : attachments) {
-                            if (att.getFilename().equals(filename)) {
+                            if(filename.equals(att.getFilename())) {
                                 found = true;
                             }
                         }
@@ -877,7 +901,7 @@ public class Incoming {
                     }
                     if (pgpmime) {
                         GuardEMailDecryptionService decryptionService = new GuardEMailDecryptionServiceImpl();
-                        PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(ck, session, userAgent, folder, emailid, att.get("filename").getAsString(), userid, cid, password);
+                        PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(ck, session, userAgent, folder, emailid, att.get("filename").getAsString(), userid, cid, password, ServletUtils.getClientIP(request));
                         decattach.setContent(IOUtils.toByteArray(decryptionResult.getInputStream()));
                     } else {
                         //Get a Stream to the attachment
@@ -1108,7 +1132,7 @@ public class Incoming {
                                     for (InlineImageHandler inlineImageHandler : inlineImageHandlers) {
                                         //Getting an appropriated handler for receiving the inline image from the given URL
                                         if (inlineImageHandler.canHandle(url)) {
-                                            inlineImage = inlineImageHandler.handle(url, ck, session, userAgent, userId, contextId);
+                                            inlineImage = inlineImageHandler.handle(url, ck, session, userAgent, userId, contextId, ServletUtils.getClientIP(request));
                                             if (inlineImage != null) {
                                                 break;
                                             }
