@@ -83,9 +83,9 @@ import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.GuardMasterKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.PGPUtils;
 import net.htmlparser.jericho.Source;
@@ -115,8 +115,9 @@ public class SignMime {
         	error.add("error", message);
         	if (ex.getCode() == GuardAuthExceptionCodes.BAD_PASSWORD.getNumber()) {
         		ServletUtils.sendAnswer(response, 401, error.toString());
-        	} else
-        		ServletUtils.sendNotAcceptable(response, error.toString());
+        	} else {
+                ServletUtils.sendNotAcceptable(response, error.toString());
+            }
         }
 
     }
@@ -376,7 +377,7 @@ public class SignMime {
     	MimeMessage msg = new MimeMessage(message);
     	Enumeration<Header> headers = msg.getAllHeaders();
     	while (headers.hasMoreElements()) {
-    		Header h = (Header) headers.nextElement();
+    		Header h = headers.nextElement();
     		String name = h.getName();
     		if (name != null && !name.contains("Content")) {
         		msg.removeHeader(h.getName());
