@@ -54,6 +54,7 @@ import java.util.Iterator;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.bouncycastle.openpgp.PGPKeyRing;
+import org.bouncycastle.openpgp.PGPPublicKeyRing;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonObject;
@@ -62,9 +63,11 @@ import com.openexchange.guard.email.storage.ogEmail.Email;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.handler.ResponseHandler;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.util.PGPMergeUtil;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
@@ -129,7 +132,7 @@ public class PublicKeyImporter {
         newkey.setPGPKeyRingFromAsc(data);
 
         // Make sure the key has the email in userids
-        if (!hasUserID(newkey.getPublicKeyRing(), email)) {
+        if (!hasUserID(newkey.getPGPPublicKeyRing(), email)) {
             logger.debug("User email address not found in the uploaded public keys");
             ServletUtils.sendError(response, "Bad UID");
             return;
@@ -149,11 +152,17 @@ public class PublicKeyImporter {
                 ServletUtils.sendError(response, "Private key exists, merge not supported through mailvelope");
                 return;
             }
-            if ((newkey.setPublicKeyRing(pk.handleDuplicatePublic(newkey, existing, dupl))) == null) {
+            PGPPublicKeyRing mergedKeyRings = PGPMergeUtil.mergeKeyRings(newkey.getPGPPublicKeyRing(), existing.getPGPPublicKeyRing());
+            if (mergedKeyRings == null) {
                 logger.error("Problem handling duplicate public key");
                 ServletUtils.sendError(response, "duplicate error");
                 return;
             }
+            else {
+                newkey.setPGPPublicKeyRing(mergedKeyRings);
+                PGPKeysStorage keysStorage = Services.getService(PGPKeysStorage.class);
+                keysStorage.addPublicKeyIndex(existing.getContextid(), existing.getKeyid(), existing.getEmail(), existing.getPGPPublicKeyRing());
+            }
             KeyTableStorage ks = Services.getService(KeyTableStorage.class);
             ks.updatePublicKey(newkey);
 
