@@ -53,14 +53,16 @@ import org.osgi.service.http.HttpService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.config.ConfigTools;
+import com.openexchange.context.ContextService;
 import com.openexchange.guard.GuardMaintenanceService;
-import com.openexchange.guard.bad.GuardBadStorage;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.cron.CleanAuthenticationTokenTask;
 import com.openexchange.guard.cron.CleanFileCacheTask;
 import com.openexchange.guard.cron.CleanRemoteKeyCacheTask;
+import com.openexchange.guard.cron.CleanTemporaryTokensTask;
 import com.openexchange.guard.cron.DailyTaskScheduler;
 import com.openexchange.guard.cron.ResetExposedKeysTask;
 import com.openexchange.guard.database.GuardDatabaseService;
@@ -68,22 +70,30 @@ import com.openexchange.guard.database.GuardShardingService;
 import com.openexchange.guard.dns.DNSService;
 import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
+import com.openexchange.guard.guestreset.GuestResetService;
+import com.openexchange.guard.guestreset.storage.TemporaryTokenService;
 import com.openexchange.guard.guestupgrade.GuestUpgradeService;
 import com.openexchange.guard.handler.ResponseHandler;
 import com.openexchange.guard.handler.impl.ResponseHandlerImpl;
+import com.openexchange.guard.hkpclient.services.HKPClientService;
 import com.openexchange.guard.internal.GuardMaintenanceServiceImpl;
 import com.openexchange.guard.internal.GuardVersion;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.GuardMasterKeyService;
-import com.openexchange.guard.keys.HKPClientService;
+import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.KeyCreationService;
+import com.openexchange.guard.keymanagement.services.KeyImportService;
+import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.services.PasswordChangeService;
+import com.openexchange.guard.keymanagement.services.PublicExternalKeyService;
+import com.openexchange.guard.keymanagement.services.RecipKeyService;
+import com.openexchange.guard.keymanagement.storage.DeletedKeysStorage;
+import com.openexchange.guard.keymanagement.storage.KeyCacheStorage;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
+import com.openexchange.guard.keymanagement.storage.RemoteKeyCacheStorage;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.PublicKeyService;
-import com.openexchange.guard.keys.storage.DeletedKeysStorage;
-import com.openexchange.guard.keys.storage.KeyCacheStorage;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
-import com.openexchange.guard.keys.storage.OGPGPKeysStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
-import com.openexchange.guard.keys.storage.RemoteKeyCacheStorage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.mailvelope.MailvelopeStorage;
 import com.openexchange.guard.mailvelope.internal.MailvelopeStorageImpl;
@@ -100,6 +110,7 @@ import com.openexchange.guard.storage.Storage;
 import com.openexchange.guard.storage.cache.FileCacheStorage;
 import com.openexchange.guard.translation.GuardTranslationService;
 import com.openexchange.guard.update.GuardUpdateService;
+import com.openexchange.guard.user.GuardUserService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.startup.SignalHttpApiAvailabilityService;
 import com.openexchange.timer.TimerService;
@@ -117,7 +128,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.DeferredActivator#getNeededServices()
      */
     @Override
@@ -125,16 +136,18 @@ public class GuardServiceActivator extends HousekeepingActivator {
         return new Class<?>[] { HttpService.class, SignalHttpApiAvailabilityService.class,
             GuardConfigurationService.class, GuardMasterKeyService.class, TimerService.class, GuardTranslationService.class,
             GuardRatifierService.class, GuardCipherFactoryService.class, GuardDatabaseService.class, GuardSessionService.class,
-            KeyCacheStorage.class, PublicKeyService.class, MailCreatorService.class, DNSService.class, PGPKeyService.class, GlobalSettingsStorage.class,
-            GuardNotificationService.class, GuardBadStorage.class, GuardKeyService.class, EmailStorage.class,
+            KeyCacheStorage.class, RecipKeyService.class, MailCreatorService.class, DNSService.class, PGPKeyService.class, GlobalSettingsStorage.class,
+            GuardNotificationService.class, GuardAntiAbuseService.class, GuardKeyService.class, EmailStorage.class,
             GuardShardingService.class, KeyTableStorage.class, PGPKeysStorage.class, EncryptedItemsStorage.class, OGPGPKeysStorage.class,
             DeletedKeysStorage.class, Storage.class, GuardUpdateService.class, GuestUpgradeService.class, HKPClientService.class,
-            PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class };
+            PGPCryptoService.class, PGPSigningService.class, TokenAuthenticationService.class, FileCacheStorage.class, RemoteKeyCacheStorage.class,
+            GuestResetService.class, TemporaryTokenService.class, KeyCreationService.class, GuardUserService.class, KeyRecoveryService.class,
+            PasswordChangeService.class, AccountCreationService.class, PublicExternalKeyService.class, KeyImportService.class, ContextService.class };
     }
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.DeferredActivator#startBundle()
      */
     @Override
@@ -169,6 +182,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
         dailyJobScheduler.register(new CleanFileCacheTask(guardConfigurationService.getIntProperty(GuardProperty.cacheDays)));
         dailyJobScheduler.register(new CleanRemoteKeyCacheTask(guardConfigurationService.getIntProperty(GuardProperty.pgpCacheDays)));
         dailyJobScheduler.register(new CleanAuthenticationTokenTask(ConfigTools.parseTimespan(guardConfigurationService.getProperty(GuardProperty.authLifeTime))));
+        dailyJobScheduler.register(new CleanTemporaryTokensTask(guardConfigurationService.getIntProperty(GuardProperty.temporaryTokenLifespan)));
         int exposedKeyDurationInHours = guardConfigurationService.getIntProperty(GuardProperty.exposedKeyDurationInHours);
         if (exposedKeyDurationInHours > 0) {
             dailyJobScheduler.register(new ResetExposedKeysTask(exposedKeyDurationInHours));
@@ -180,7 +194,7 @@ public class GuardServiceActivator extends HousekeepingActivator {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.osgi.DeferredActivator#stopBundle()
      */
     @Override
