@@ -53,7 +53,7 @@ import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.security.PrivateKey;
 import java.util.ArrayList;
-import java.util.Arrays;
+import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
@@ -63,12 +63,9 @@ import org.apache.commons.fileupload.FileItemFactory;
 import org.apache.commons.fileupload.disk.DiskFileItemFactory;
 import org.apache.commons.fileupload.servlet.ServletFileUpload;
 import org.apache.commons.io.IOUtils;
-import org.bouncycastle.openpgp.PGPException;
 import org.bouncycastle.openpgp.PGPPrivateKey;
 import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
-import org.bouncycastle.openpgp.PGPSignature;
-import org.bouncycastle.openpgp.PGPUserAttributeSubpacketVector;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.google.gson.JsonElement;
@@ -76,21 +73,24 @@ import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.common.util.JsonUtil;
+import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.handler.ResponseHandler;
-import com.openexchange.guard.internal.Auth;
-import com.openexchange.guard.internal.GuardSettings;
-import com.openexchange.guard.internal.Settings;
 import com.openexchange.guard.internal.UserData;
-import com.openexchange.guard.keys.GuardKeyService;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.PGPKeys;
+import com.openexchange.guard.keymanagement.commons.util.PGPMergeUtil;
+import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.KeyRecoveryService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.PGPKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
+import com.openexchange.guard.user.GuardCapabilities;
+import com.openexchange.guard.user.GuardUserService;
 
 public class PGPPrivateKeyHandler {
 
@@ -178,11 +178,11 @@ public class PGPPrivateKeyHandler {
         }
         if (pubdata.equals("")) {
             PGPPublicKeyRing publicKeyRing = pgpKeyService.createPublicKeyRingFromPrivateKey(newkey.getPGPSecretKeyRing());
-            newkey.setPublicKeyRing(publicKeyRing);
+            newkey.setPGPPublicKeyRing(publicKeyRing);
 
         } else {
             newkey.setPGPKeyRingFromAsc(pubdata);
-            if (newkey.getPublicKeyRing() == null) {
+            if (newkey.getPGPPublicKeyRing() == null) {
                 LOG.info("Problem with pub keys");
                 ServletUtils.sendNotAcceptable(response, "Problem with pub keys");
                 return;
@@ -194,11 +194,10 @@ public class PGPPrivateKeyHandler {
             newkey.setContextid(api.getContextId());
             newkey.setUserid(userid);
             newkey.setLanguage(language);
-            //TODO:
-            //version,question,answer,settings?
 
             // Mkae sure the IDs of the new public key are same as the user
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
+            KeyRecoveryService recoveryService = Services.getService(KeyRecoveryService.class);
             if (verifyID(newkey)) {
                 Long dupl;
                 boolean duplicate = false;
@@ -208,27 +207,39 @@ public class PGPPrivateKeyHandler {
 
                 // Create recovery
                 if (password != null) {
-                    if (GuardSettings.checkCreateRecovery(cookie, request)) {
-                        newkey.setRecovery(keyService.createRecovery(newkey, password));
+                    if (recoveryService.checkCreateRecovery(cid, userid)) {
+                        newkey.setRecovery(recoveryService.createRecovery(newkey, password));
                     }
                 }
 
                 if (!duplicate) {  // Not duplicate, add
+                    GuardKeys oldkey = keyService.getKeys(userid, cid);  // Retrieve old key for settings
                     keyService.addNewKey(newkey);
+                    if(oldkey != null) {
+                        keyService.updateSettingsForUser(oldkey); // Update new key with prior settings if available
+                        keyService.updateAnswerQuestionForUser(oldkey);
+                    }
                 } else {
                     GuardKeys existing = PGPPublicHandler.getKeyForPGP(userid, cid, dupl, true);
 
-                    if (!PGPUtils.verifyPassword(password, existing.getSalt(), existing.getPGPSecretKeyRing())) {
+                    if (!PGPUtil.verifyPassword(existing.getPGPSecretKeyRing(), password, existing.getSalt())) {
                         ServletUtils.sendNotAcceptable(response, "Bad Merge Password");
                         return;
                     }
 
                     //////////// HANDLE MERGE/DUPLICATE public keys
-                    if ((newkey.setPublicKeyRing(handleDuplicatePublic(newkey, existing, dupl))) == null) {
+                    PGPPublicKeyRing mergedKeyRings = PGPMergeUtil.mergeKeyRings(newkey.getPGPPublicKeyRing(), existing.getPGPPublicKeyRing());
+                    if (mergedKeyRings == null) {
                         LOG.error("Problem handling duplicate public key");
                         ServletUtils.sendNotAcceptable(response, "duplicate error");
                         return;
                     }
+                    else {
+                        //Setting merged data
+                        newkey.setPGPPublicKeyRing(mergedKeyRings);
+                        PGPKeysStorage keysStorage = Services.getService(PGPKeysStorage.class);
+                        keysStorage.addPublicKeyIndex(existing.getContextid(), existing.getKeyid(), existing.getEmail(), mergedKeyRings);
+                    }
                     if (newkey.getPGPSecretKeyRing() == null) {  // If overwriting public only, and we have a private for that key, keep it and only update PubRing
                         if (existing.getPGPSecretKeyRing() != null) {
                             KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
@@ -238,11 +249,13 @@ public class PGPPrivateKeyHandler {
                         // Update the key
                         newkey = updateOldGuardKey(newkey, existing, password);
                         if (password != null) {  // RSA public key changed and need to rehash the recovery password
-                            if (GuardSettings.checkCreateRecovery(cookie, request)) {
-                                newkey.setRecovery(keyService.createRecovery(newkey, password));
+                            if (recoveryService.checkCreateRecovery(cid, userid)) {
+                                newkey.setRecovery(recoveryService.createRecovery(newkey, password));
                             }
                         }
-                        pgpKeyService.updateDuplicatePGPKey(userid, cid, newkey, newkey.getRecovery(), dupl);
+                        newkey.setKeyid(dupl);
+                        KeyTableStorage keyTable = Services.getService(KeyTableStorage.class);
+                        keyTable.updateDuplicate(newkey);
                     }
                 }
 
@@ -274,7 +287,7 @@ public class PGPPrivateKeyHandler {
      * @return
      */
     private boolean verifyID(GuardKeys gkey) {
-        Iterator keys = gkey.getPublicKeyRing().getPublicKeys();
+        Iterator keys = gkey.getPGPPublicKeyRing().getPublicKeys();
         PGPPublicKey key = null;
         while (keys.hasNext()) {
             key = (PGPPublicKey) keys.next();
@@ -290,44 +303,6 @@ public class PGPPrivateKeyHandler {
         return (false);
     }
 
-    /**
-     * Handle an upload of a public key that already exists
-     *
-     * @param gkey
-     * @param dupl
-     * @return
-     */
-
-    public PGPPublicKeyRing handleDuplicatePublic(GuardKeys gkey, GuardKeys existing, long dupl) {
-
-        try {
-            Iterator<PGPPublicKey> keys = gkey.getPublicKeyRing().getPublicKeys();
-            // get the guardkeys that has the duplicated public key
-
-            while (keys.hasNext()) {
-                PGPPublicKey keyToImport = keys.next();
-                long importID = keyToImport.getKeyID();
-                PGPPublicKey toMerge = existing.getPublicKeyRing().getPublicKey(importID);
-                if (toMerge != null) {
-                    existing.setPublicKeyRing(PGPPublicKeyRing.removePublicKey(existing.getPublicKeyRing(), toMerge));
-                    toMerge = mergeKeys(toMerge, keyToImport);
-                    if (toMerge == null) {
-                        return null;
-                    }
-                    existing.setPublicKeyRing(PGPPublicKeyRing.insertPublicKey(existing.getPublicKeyRing(), toMerge));
-                } else {
-                    existing.setPublicKeyRing(PGPPublicKeyRing.insertPublicKey(existing.getPublicKeyRing(), keyToImport));
-                }
-            }
-            PGPKeysStorage keysStorage = Services.getService(PGPKeysStorage.class);
-            keysStorage.addPublicKeyIndex(existing.getContextid(), existing.getKeyid(), existing.getEmail(), existing.getPublicKeyRing());
-            return existing.getPublicKeyRing();
-        } catch (Exception e) {
-            LOG.error("Problem merging duplicate public keys, ", e);
-            return existing.getPublicKeyRing();
-        }
-    }
-
     /**
      * Since the salt changes, we need to re-encrypt the old Guard proprietary priv key.
      *
@@ -369,7 +344,8 @@ public class PGPPrivateKeyHandler {
             LOG.info("Delete private key...not logged in");
             return;
         }
-        Settings settings = new Auth().getPermissions(ck, request);
+        ;
+        GuardCapabilities  settings = Services.getService(GuardUserService.class).getGuardCapabilieties(cid, userid);
         if (settings.isNoDeletePrivate()) {
             ServletUtils.sendNotAcceptable(response, "Function disabled by configuration");
             return;
@@ -402,9 +378,9 @@ public class PGPPrivateKeyHandler {
             return;
         }
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys key = keyService.getKeys(userid, cid, keyid, false);
+        GuardKeys key = keyService.getKeys(userid, cid, keyid);
         // Make sure right password for this key
-        if (!PGPUtils.verifyPassword(data.getEncr_password(), key.getSalt(), key.getPGPSecretKeyRing())) {
+        if (!PGPUtil.verifyPassword( key.getPGPSecretKeyRing(), data.getEncr_password(), key.getSalt())) {
             ServletUtils.sendNotAcceptable(response, "Bad password");
             LOG.info("Bad password");
             return;
@@ -421,6 +397,15 @@ public class PGPPrivateKeyHandler {
         if (iscurrent) {
             resetCurrentKey(userid, cid);
         }
+
+        //Check if the user has other keys
+        Collection<GuardKeys> allKeys = Services.getService(GuardKeyService.class).getAllKeys(userid, cid);
+        if(allKeys == null || allKeys.size() == 0) {
+            //no keys left; we can delete the email mapping
+            EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+            ogEmailStorage.deleteAllForUser(cid, userid);
+        }
+
         ServletUtils.sendHtmlOK(response, "OK");
         LOG.debug("Success deleting private key");
 
@@ -478,9 +463,9 @@ public class PGPPrivateKeyHandler {
             return;
         }
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys key = keyService.getKeys(userid, cid, keyid, false);
+        GuardKeys key = keyService.getKeys(userid, cid, keyid);
         // Make sure right password for this key
-        if (!PGPUtils.verifyPassword(data.getEncr_password(), key.getSalt(), key.getPGPSecretKeyRing())) {
+        if (!PGPUtil.verifyPassword(key.getPGPSecretKeyRing(), data.getEncr_password(), key.getSalt())) {
             ServletUtils.sendNotAcceptable(response, "Bad password");
             LOG.info("Bad password");
             return;
@@ -524,7 +509,7 @@ public class PGPPrivateKeyHandler {
         }
 
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys key = keyService.getKeys(userid, cid, keyid, false);
+        GuardKeys key = keyService.getKeys(userid, cid, keyid);
         if (key == null) {
             ServletUtils.sendNotAcceptable(response, "Unable to find key");
             LOG.info("Fail, unable to find key");
@@ -546,99 +531,15 @@ public class PGPPrivateKeyHandler {
         if (key.isCurrent()) {
             resetCurrentKey(userid, cid);
         }
-    }
 
-    /**
-     * Add/Merge certifications of two public keys
-     *
-     * @param old
-     * @param newKey
-     * @return
-     * @throws PGPException
-     */
-    private PGPPublicKey mergeKeys(PGPPublicKey old, PGPPublicKey newKey) throws PGPException {
-        if (old.getKeyID() != newKey.getKeyID()) {
-            LOG.error("Unable to merge keys, different keyids ");
-            return (null);
-        }
-        ArrayList<PGPSignature> oldsigs = new ArrayList<PGPSignature>();
-        Iterator oldsigI = old.getSignatures();
-        while (oldsigI.hasNext()) {
-            oldsigs.add((PGPSignature) oldsigI.next());
+        //Check if the user has other keys
+        Collection<GuardKeys> allKeys = Services.getService(GuardKeyService.class).getAllKeys(userid, cid);
+        if(allKeys == null || allKeys.size() == 0) {
+            //no keys left; we can delete the email mapping
+            EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
+            ogEmailStorage.deleteAllForUser(cid, userid);
         }
 
-        Iterator<String> userids = old.getUserIDs();
-        // Loop through userids of the old certificate and see if there are any new signatures
-        while (userids.hasNext()) {
-            String uid = userids.next();
-            Iterator<PGPSignature> newsigs = newKey.getSignaturesForID(uid);
-            if (newsigs != null) {
-                while (newsigs.hasNext()) {
-                    PGPSignature newsig = newsigs.next();
-                    if (!hasSig(newsig, oldsigs)) {
-                        old = PGPPublicKey.addCertification(old, uid, newsig);
-                    }
-                }
-            }
-
-        }
-        userids = newKey.getUserIDs();
-        // Loop through userids of the NEW certificate and see if there are any new signatures
-        while (userids.hasNext()) {
-            String uid = userids.next();
-            Iterator<PGPSignature> newsigs = newKey.getSignaturesForID(uid);
-            while (newsigs.hasNext()) {
-                PGPSignature newsig = newsigs.next();
-                if (!hasSig(newsig, oldsigs)) {
-                    old = PGPPublicKey.addCertification(old, uid, newsig);
-                }
-            }
-        }
-        // Loop through user attributes and see if any new signatures
-        Iterator<PGPUserAttributeSubpacketVector> vectors = old.getUserAttributes();
-        while (vectors.hasNext()) {
-            PGPUserAttributeSubpacketVector vector = vectors.next();
-            Iterator<PGPSignature> newsigs = newKey.getSignaturesForUserAttribute(vector);
-            while (newsigs.hasNext()) {
-                PGPSignature newsig = newsigs.next();
-                if (!hasSig(newsig, oldsigs)) {
-                    old = PGPPublicKey.addCertification(old, vector, newsig);
-                }
-            }
-        }
-        // Loop through user attributes and see if any new signatures
-        vectors = newKey.getUserAttributes();
-        while (vectors.hasNext()) {
-            PGPUserAttributeSubpacketVector vector = vectors.next();
-            Iterator<PGPSignature> newsigs = newKey.getSignaturesForUserAttribute(vector);
-            if (newsigs != null) {
-                while (newsigs.hasNext()) {
-                    PGPSignature newsig = newsigs.next();
-                    if (!hasSig(newsig, oldsigs)) {
-                        old = PGPPublicKey.addCertification(old, vector, newsig);
-                    }
-                }
-            }
-        }
-
-        // Check for revoke signatures
-        Iterator<PGPSignature> newsigs = newKey.getSignaturesOfType(PGPSignature.KEY_REVOCATION);
-        while (newsigs.hasNext()) {
-            PGPSignature newsig = newsigs.next();
-            if (!hasSig(newsig, oldsigs)) {
-                old = PGPPublicKey.addCertification(old, newsig);
-            }
-        }
-        return (old);
-    }
-
-    private boolean hasSig(PGPSignature sig, ArrayList<PGPSignature> sigs) throws PGPException {
-        for (int i = 0; i < sigs.size(); i++) {
-            if (Arrays.equals(sig.getSignature(), sigs.get(i).getSignature())) {
-                return (true);
-            }
-        }
-        return (false);
     }
 
     /**
@@ -651,7 +552,7 @@ public class PGPPrivateKeyHandler {
 
     public long isDuplicate(GuardKeys gkey) throws Exception {
         List<Long> ids = new ArrayList<Long>();
-        Iterator<PGPPublicKey> keys = gkey.getPublicKeyRing().getPublicKeys();
+        Iterator<PGPPublicKey> keys = gkey.getPGPPublicKeyRing().getPublicKeys();
         while (keys.hasNext()) {
             ids.add(keys.next().getKeyID());
         }
@@ -666,50 +567,6 @@ public class PGPPrivateKeyHandler {
 
     }
 
-    /**
-     * Make the keyid the current key
-     *
-     * @param id
-     * @param cid
-     * @param keyid
-     * @return
-     * @throws Exception
-     */
-    public static void makeCurrent(int id, int cid, String keyid) throws Exception {
-        KeyTableStorage ogKeyTableStorage = Services.getService(KeyTableStorage.class);
-
-        //Getting the key which should be marked as "current"
-        GuardKeys key = ogKeyTableStorage.getKeyForUserById(id, cid, keyid);
-        if (key != null) {
-            //Removing the current flag from all keys
-            ogKeyTableStorage.unsetCurrentFlag(id, cid);
-
-            //Setting the current flag to the key
-            ogKeyTableStorage.setCurrentKey(key);
-        } else {
-            throw new IllegalArgumentException("Key Not Found");
-        }
-    }
-
-    /**
-     * Make a selected Private/Public key pair the current one to be used.
-     *
-     * @param request
-     * @param response
-     * @param ck
-     * @throws Exception
-     */
-    public void makeCurrent(HttpServletRequest request, HttpServletResponse response, int userid, int cid, OxCookie ck) throws Exception {
-        Api ap = new Api(ck, request);
-        if (!ap.verifyLogin()) {
-            ServletUtils.sendNotAcceptable(response, "Must be logged in");
-            return;
-        }
-
-        String keyid = ServletUtils.getStringParameter(request, "keyid", true);
-        makeCurrent(userid, cid, keyid);
-    }
-
     public void addUID(HttpServletRequest request, HttpServletResponse response, OxCookie ck, int userid, int cid) throws Exception {
         JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
         Api ap = new Api(ck, request);
@@ -723,7 +580,7 @@ public class PGPPrivateKeyHandler {
         String password = JsonUtil.getStringFromJson(json, "password", true);
 
         GuardKeyService keyService = Services.getService(GuardKeyService.class);
-        GuardKeys keys = keyService.getKeys(userid, cid, Long.parseLong(keyid), false);
+        GuardKeys keys = keyService.getKeys(userid, cid, Long.parseLong(keyid));
         if (keys == null) {
             throw GuardPGPExceptionCodes.KEY_NOT_FOUND.create(keyid);
         }
@@ -733,12 +590,12 @@ public class PGPPrivateKeyHandler {
         pkey = pgpKeyService.getPGPSignKey(keys.getPGPSecretKeyRing(), password, keys.getSalt());
 
         String uid = name + " <" + email + ">";
-        PGPPublicKeyRing newring = pgpKeyService.addUID(pkey, keys.getPublicKeyRing(), uid);
+        PGPPublicKeyRing newring = pgpKeyService.addUID(pkey, keys.getPGPPublicKeyRing(), uid);
         if (newring == null) {
             ServletUtils.sendNotAcceptable(response, "error adding");
             return;
         }
-        keys.setPublicKeyRing(newring);
+        keys.setPGPPublicKeyRing(newring);
         pgpKeyService.updatePGPKeys(userid, cid, keys);
         ServletUtils.sendHtmlOK(response, "OK");
     }
