@@ -81,14 +81,16 @@ import com.openexchange.guard.common.util.IDNUtil;
 import com.openexchange.guard.common.util.ListUtil;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.keys.GuardKeyService;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.OGPGPKey;
+import com.openexchange.guard.keymanagement.commons.PGPKeys;
+import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
+import com.openexchange.guard.keymanagement.commons.parsing.AsciiArmoredKeyParser;
+import com.openexchange.guard.keymanagement.commons.parsing.PGPPublicKeyRingFactory;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.storage.OGPGPKeysStorage;
+import com.openexchange.guard.keymanagement.storage.PGPKeysStorage;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.PGPPublicKeyRingFactory;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.OGPGPKey;
-import com.openexchange.guard.keys.dao.PGPKeys;
-import com.openexchange.guard.keys.storage.OGPGPKeysStorage;
-import com.openexchange.guard.keys.storage.PGPKeysStorage;
 import com.openexchange.guard.mail.Attachment;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -97,7 +99,6 @@ import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgp.decryption.GuardEMailDecryptionService;
 import com.openexchange.guard.pgp.decryption.PGPDecryptionResult;
 import com.openexchange.guard.pgp.decryption.impl.GuardEMailDecryptionServiceImpl;
-import com.openexchange.guard.pgp.parser.AsciiArmoredKeyParser;
 import com.openexchange.guard.ratifier.GuardRatifierService;
 
 public class PGPPublicHandler {
@@ -234,8 +235,7 @@ public class PGPPublicHandler {
             String email = IDNUtil.decodeEmail(addr.getAddress());
 
             //Adding the new uploaded key to the storage
-            PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
-            String asciiData = pgpKeyService.export(ring);
+            String asciiData = KeyExportUtil.export(ring);
             OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
             ogpgpKeysStorage.insertOrUpdate(userid, cid, email, keyhexids, asciiData);
 
@@ -310,7 +310,7 @@ public class PGPPublicHandler {
                 }
             } else {  // pgp mime attachment
                 GuardEMailDecryptionService decryptionService = new GuardEMailDecryptionServiceImpl();
-                PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(ck, session, userAgent, folder, emailid, filename, userid, cid, password);
+                PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentByName(ck, session, userAgent, folder, emailid, filename, userid, cid, password, ServletUtils.getClientIP(request));
                 bytedata = IOUtils.toByteArray(decryptionResult.getInputStream());
             }
             if (bytedata == null || bytedata.length < 2) {
@@ -441,9 +441,9 @@ public class PGPPublicHandler {
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
             for (int i = 0; i < emailArray.size(); i++) {
                 String email = emailArray.get(i);
-                GuardKeys gkey = keyService.getKeysFromEmail(email);
+                GuardKeys gkey = keyService.getKeys(email);
                 if (gkey != null) {
-                    JsonArray info = PgpHandler.getKeyInfo(gkey.getPublicKeyRing());
+                    JsonArray info = PgpHandler.getKeyInfo(gkey.getPGPPublicKeyRing());
                     StringBuilder idBuilder = new StringBuilder();
                     for (int j = 0; j < info.size(); j++) {
                         JsonObject keyinfo = (JsonObject) info.get(j);
@@ -465,56 +465,6 @@ public class PGPPublicHandler {
         return (ret);
     }
 
-    public void deleteKey(HttpServletRequest request, HttpServletResponse response, int userid, int cid) throws Exception {
-        String ids = ServletUtils.getStringParameter(request, "ids", true);
-        try {
-            String[] idList = ids.trim().split("\\s+");
-            OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
-            ogpgpKeysStorage.delete(userid, cid, Arrays.asList(idList));
-
-            ServletUtils.sendHtmlOK(response, "OK");
-        } catch (Exception ex) {
-            LOG.error("Problem deleting public pgp key ", ex);
-            ServletUtils.sendNotAcceptable(response, "Fail");
-        }
-    }
-
-    public void shareKey(HttpServletRequest request, HttpServletResponse response, int userid, int cid) throws Exception {
-        String ids = ServletUtils.getStringParameter(request, "ids", true);
-        String[] idList = ids.trim().split("\\s+");
-        String share = ServletUtils.getStringParameter(request, "share", true);
-        int sharelevel = share.toLowerCase().trim().equals("true") ? 1 : 0;
-        try {
-            OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
-            ogpgpKeysStorage.updateShareLevel(userid, cid, Arrays.asList(idList), sharelevel);
-
-            ServletUtils.sendHtmlOK(response, "OK");
-        } catch (Exception ex) {
-            LOG.error("Problem sharing public pgp key ", ex);
-            ServletUtils.sendNotAcceptable(response, "Fail");
-        }
-    }
-
-    public void changeInline(HttpServletRequest request, HttpServletResponse response, int userid, int cid) throws Exception {
-        String ids = ServletUtils.getStringParameter(request, "ids", true);
-        String[] idList = ids.trim().split("\\s+");
-        String inlineStr = ServletUtils.getStringParameter(request, "inline", true);
-        boolean isInline = inlineStr.toLowerCase().trim().equals("true") ? true : false;
-        try {
-            OGPGPKeysStorage ogpgpKeysStorage = Services.getService(OGPGPKeysStorage.class);
-            ogpgpKeysStorage.updateInlineMode(userid, cid, Arrays.asList(idList), isInline);
-
-            ServletUtils.sendHtmlOK(response, "OK");
-        } catch (Exception ex) {
-            LOG.error("Problem changing inline status public pgp key ", ex);
-            ServletUtils.sendNotAcceptable(response, "Fail");
-        }
-    }
-
-    public static GuardKeys getKeyForPGP(int id, int cid, long keyid) throws Exception {
-        return (getKeyForPGP(id, cid, keyid, false));
-    }
-
     /**
      * Return the Guard Keys populated with PGP data
      *
@@ -527,12 +477,14 @@ public class PGPPublicHandler {
      * @throws Exception
      */
     public static GuardKeys getKeyForPGP(int userid, int cid, long keyid, boolean incoming) throws OXException  {
-        //TODO: Use a DI-Container for resolving
         PGPKeysStorage pgpKeysStorage = Services.getService(PGPKeysStorage.class);
         PGPKeys keyMapping = pgpKeysStorage.getByKeyIdInContext(cid, keyid);
         if (keyMapping != null) {
             GuardKeyService keyService = Services.getService(GuardKeyService.class);
-            GuardKeys keys = keyService.getKeys(userid, cid, keyMapping.getKeyId(), !incoming);  // If incoming, we want all of the keys, not just the current
+            // If incoming, we want all of the keys, not just the current
+            GuardKeys keys = incoming ?
+                keyService.getKeys(userid, cid, keyMapping.getKeyId()) :
+                keyService.getKeys(userid, cid);
             return (keys);
         }
         if (incoming) {
@@ -548,7 +500,7 @@ public class PGPPublicHandler {
             GuardKeys ret = new GuardKeys();
             ret.setEmail(key.getEmail());
             try {
-                ret.setPublicKeyRing(PGPPublicKeyRingFactory.create(key.getPublicPGPAscData()));
+                ret.setPGPPublicKeyRing(PGPPublicKeyRingFactory.create(key.getPublicPGPAscData()));
             } catch (IOException e) {
                 throw GuardCoreExceptionCodes.IO_ERROR.create(e, e.getMessage());
             }
