@@ -50,9 +50,9 @@ import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.encryption.EncryptedItemsStorage;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.RecipKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mail.Attachment;
 import com.openexchange.guard.mail.GuardMimeMessage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
@@ -88,14 +88,14 @@ public class PGPSender {
         // Check if inline requested by a recipient
         List<RecipKey> recipients = mail.getRecipients();
         for (int i = 0; i < recipients.size(); i++) {
-        	if (recipients.get(i).isInline()) {
+            if (recipients.get(i).isInline()) {
                 lInline = true;
             }
         }
 
         // we need to add the sender to the list of recipients so can be read in sent folder
         RecipKey sender = new RecipKey();
-        sender.setPgpring(senderkey.getPublicKeyRing());
+        sender.setPGPPrivateKeyRing(senderkey.getPGPPublicKeyRing());
         mail.getRecipients().add(sender);
 
         if (lInline && !mail.isDraft()) {  // Drafts will be saved as PGP Mime
@@ -368,7 +368,7 @@ public class PGPSender {
                         // Guest account
                         Storage storage = Services.getService(Storage.class);
                         storage.saveEncrObj(recip.getUserid(), recip.getCid(), id, encrypted.toByteArray());
-                        JsonObject email = mailCreatorService.createBlankGuestMail(recip.getLang(), mail.getTemplateId(), messageId, host, senderId, senderCid);
+                        JsonObject email = mailCreatorService.createBlankGuestMail(recip.getLang(), mail.getTemplateId(), messageId, host, senderId, senderCid, mail.getGuestmessage());
                         if (email == null) {
                             return ("Unable to create template");
                         }
@@ -384,7 +384,7 @@ public class PGPSender {
                             data.get("headers").getAsJsonObject().addProperty("X-OXGUARD-GUEST", "true");
                             if (data.has("disp_notification_to")) {  // Add return receipt request if needed
                                 if (data.get("disp_notification_to").getAsBoolean()) {
-                                	email.get("data").getAsJsonObject().addProperty("disp_notification_to", true);
+                                    email.get("data").getAsJsonObject().addProperty("disp_notification_to", true);
                                 }
                             }
                         } catch (Exception ex) {
@@ -396,8 +396,12 @@ public class PGPSender {
                             if (url == null || url.isEmpty()) {
                                 url = "https://" + guardConfigService.getProperty(GuardProperty.externalReaderPath);
                             }
+                            String newGuest = "";
+                            if (recip.getNewGuestPass() != null && !guardConfigService.getBooleanProperty(GuardProperty.newGuestsRequirePassword)) {
+                                newGuest = "&newGuest=true";
+                            }
                             GuardTranslationService translationService = Services.getService(GuardTranslationService.class);
-                            email = mailCreatorService.addURL(email, url + "?email=" + id + "&user=" + URLEncoder.encode(recip.getEmail(), "UTF-8") + (translationService.customTemplateExists(mail.getTemplateId(), "guesttempl.html") ? ("&templid=" + mail.getTemplateId()) : "") + "&lang=" + recip.getLang());
+                            email = mailCreatorService.addURL(email, url + "?email=" + id + "&user=" + URLEncoder.encode(recip.getEmail(), "UTF-8") + (translationService.customTemplateExists(mail.getTemplateId(), "guesttempl.html") ? ("&templid=" + mail.getTemplateId()) : "") + "&lang=" + recip.getLang() + newGuest);
                         } catch (UnsupportedEncodingException e) {
                             email = mailCreatorService.addURL(email, "https://" + guardConfigService.getProperty(GuardProperty.externalReaderPath) + "?email=" + id);
                         }
