@@ -6,8 +6,8 @@ import org.bouncycastle.openpgp.PGPPublicKey;
 import org.bouncycastle.openpgp.PGPPublicKeyRing;
 
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.osgi.Services;
 
 /**
@@ -28,7 +28,7 @@ public class PGPUserIdChecker {
 	public static boolean checkHasUID (int userid, int cid, String email) throws OXException {
 		GuardKeyService keyService = Services.getService(GuardKeyService.class);
         GuardKeys senderKeys = keyService.getKeys(userid, cid);
-        PGPPublicKeyRing ring = senderKeys.getPublicKeyRing();
+        PGPPublicKeyRing ring = senderKeys.getPGPPublicKeyRing();
         Iterator<PGPPublicKey> keys = ring.getPublicKeys();
         while (keys.hasNext()) {
         	PGPPublicKey key = keys.next();
@@ -36,7 +36,9 @@ public class PGPUserIdChecker {
         	while (ids.hasNext()) {
         		String id = ids.next();
         		if (id != null) {
-        			if (id.toLowerCase().contains(email)) return (true);
+        			if (id.toLowerCase().contains(email)) {
+                        return (true);
+                    }
         		}
         	}
         }
