@@ -99,11 +99,11 @@ import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.common.util.LongUtil;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
-import com.openexchange.guard.keys.HKPClientService;
+import com.openexchange.guard.hkpclient.services.HKPClientService;
+import com.openexchange.guard.hkpclient.services.RemoteKeyResult;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
 import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.RecipKey;
-import com.openexchange.guard.keys.internal.hkpclient.RemoteKeyResult;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
 import com.openexchange.guard.session.GuardSessionService;
@@ -145,7 +145,7 @@ public class PGPUtils {
      * @throws PGPException
      */
     public static PGPResult decryptFile(InputStream in, OutputStream fOut, int userid, int cid, String password, boolean close) throws IOException, OXException, PGPException {
-    	return decryptFile (in, fOut, userid, cid, password, close, null);
+        return decryptFile (in, fOut, userid, cid, password, close, null);
     }
 
     /**
@@ -166,10 +166,10 @@ public class PGPUtils {
     public static PGPResult decryptFile(InputStream in, OutputStream fOut, int userid, int cid, String password, boolean close, String fromAddress) throws IOException, OXException, PGPException {
 
         if (password == null || password.isEmpty()) {
-        	LOG.info("Bad password");
+            LOG.info("Bad password");
             throw GuardPGPExceptionCodes.BAD_PASSWORD_ERROR.create();
         }
-    	PGPResult result = new PGPResult();
+        PGPResult result = new PGPResult();
         in = PGPUtil.getDecoderStream(in);
         PGPObjectFactory pgpF = new PGPObjectFactory(in, new BcKeyFingerprintCalculator());
         PGPEncryptedDataList enc;
@@ -218,7 +218,7 @@ public class PGPUtils {
                     return (result);
                 }
                 try {
-                    sKey = com.openexchange.guard.keys.util.PGPUtil.decodePrivate(protectedSKey, password, keys.getSalt());
+                    sKey = com.openexchange.guard.keymanagement.commons.util.PGPUtil.decodePrivate(protectedSKey, password, keys.getSalt());
                 } catch (org.bouncycastle.openpgp.PGPException ex) {
                     LOG.info("Bad password");
                     throw GuardPGPExceptionCodes.BAD_PASSWORD_ERROR.create();
@@ -275,7 +275,7 @@ public class PGPUtils {
                 PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
                 pgpRing = pgpKeyService.getPublicKeyRingById(ops.getKeyID(), userid, cid);
                 if (pgpRing == null) {
-                	pgpRing = checkPublicKeys(ops.getKeyID(), fromAddress, result);
+                    pgpRing = checkPublicKeys(ops.getKeyID(), fromAddress, result);
                 }
                 result.setSignature(true);
                 if (pgpRing != null) {
@@ -353,14 +353,14 @@ public class PGPUtils {
             PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
             PGPPublicKeyRing pgpRing = pgpKeyService.getPublicKeyRingById(signature.getKeyID(), userid, cid);
             if (pgpRing == null) {
-            	pgpRing = checkPublicKeys(signature.getKeyID(), fromAddress, result);
-	        	if (pgpRing == null) {
-	                LOG.info("Unable to find pgpRing for sender");
-	                result.setError("No public key");
-	                result.setVerified(false);
-	                result.setMissingPublicKey(true);
-	                return (result);
-	        	}
+                pgpRing = checkPublicKeys(signature.getKeyID(), fromAddress, result);
+                if (pgpRing == null) {
+                    LOG.info("Unable to find pgpRing for sender");
+                    result.setError("No public key");
+                    result.setVerified(false);
+                    result.setMissingPublicKey(true);
+                    return (result);
+                }
             }
             PGPPublicKey publicKey = pgpRing.getPublicKey(signature.getKeyID());
             signature.init(new JcaPGPContentVerifierBuilderProvider().setProvider("BC"), publicKey);
@@ -425,14 +425,14 @@ public class PGPUtils {
         PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
         PGPPublicKeyRing pgpRing = pgpKeyService.getPublicKeyRingById(sig.getKeyID(), userid, cid);
         if (pgpRing == null) {
-        	pgpRing = checkPublicKeys(sig.getKeyID(), fromAddress, result);
-        	if (pgpRing == null) {
+            pgpRing = checkPublicKeys(sig.getKeyID(), fromAddress, result);
+            if (pgpRing == null) {
                 LOG.info("Unable to find pgpRing for sender");
                 result.setError("No public key");
                 result.setVerified(false);
                 result.setMissingPublicKey(true);
                 return (result);
-        	}
+            }
         }
         //	PGPPublicKeyRing pgpRing = gkey.pubring;
 
@@ -461,15 +461,15 @@ public class PGPUtils {
     }
 
     private static PGPPublicKeyRing checkPublicKeys (Long id, String fromEmail, PGPResult result) throws OXException {
-    	HKPClientService hkpClient = Services.getService(HKPClientService.class);
-    	RemoteKeyResult remote = hkpClient.find(null, id, fromEmail);
-    	if (remote.hasResult()) {
-    		if (remote.getSource().isTrusted()) {
-    			result.setSource(remote.getSource());
-    			return remote.getRing();
-    		}
-    	}
-    	return null;
+        HKPClientService hkpClient = Services.getService(HKPClientService.class);
+        RemoteKeyResult remote = hkpClient.find(null, fromEmail, id);
+        if (remote != null && remote.hasResult()) {
+            if (remote.getSource().isTrusted()) {
+                result.setSource(remote.getSource());
+                return remote.getRing();
+            }
+        }
+        return null;
 
     }
 
@@ -485,8 +485,9 @@ public class PGPUtils {
      * @throws IOException
      * @throws NoSuchProviderException
      * @throws PGPException
+     * @throws OXException
      */
-    public static void encrypt(OutputStream out, byte[] data, String fileName, List<RecipKey> recipients, boolean armor, boolean withIntegrityCheck) throws IOException, NoSuchProviderException, PGPException {
+    public static void encrypt(OutputStream out, byte[] data, String fileName, List<RecipKey> recipients, boolean armor, boolean withIntegrityCheck) throws IOException, NoSuchProviderException, PGPException, OXException {
         ByteArrayInputStream in = new ByteArrayInputStream(data);
         encrypt(out, in, fileName, recipients, armor, withIntegrityCheck);
     }
@@ -503,8 +504,9 @@ public class PGPUtils {
      * @throws IOException
      * @throws NoSuchProviderException
      * @throws PGPException
+     * @throws OXException
      */
-    public static void encrypt(OutputStream out, InputStream in, String fileName, List<RecipKey> recipients, boolean armor, boolean withIntegrityCheck) throws IOException, NoSuchProviderException, PGPException {
+    public static void encrypt(OutputStream out, InputStream in, String fileName, List<RecipKey> recipients, boolean armor, boolean withIntegrityCheck) throws IOException, NoSuchProviderException, PGPException, OXException {
         if (armor) {
             out = new ArmoredOutputStream(out);
         }
@@ -514,8 +516,12 @@ public class PGPUtils {
         builder.setWithIntegrityPacket(true);
         PGPEncryptedDataGenerator encryptedDataGenerator = new PGPEncryptedDataGenerator(builder);
         for (int i = 0; i < recipients.size(); i++) {
-            if (recipients.get(i).getPgpring() != null) {
-                BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(getCryptKey(recipients.get(i).getPgpring()));
+            if (recipients.get(i).getPGPPublicKeyRing() != null) {
+                PGPPublicKey pubkey = getCryptKey(recipients.get(i).getPGPPublicKeyRing());
+                if (pubkey == null) {  // If no valid key found, quit
+                    throw GuardPGPExceptionCodes.NO_VALID_KEY.create();
+                }
+                BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(pubkey);
                 encryptedDataGenerator.addMethod(encKeyGen);
             }
         }
@@ -555,14 +561,14 @@ public class PGPUtils {
         Iterator it = ring.getPublicKeys();
         while (it.hasNext()) {
             PGPPublicKey key = (PGPPublicKey) it.next();
-            if (com.openexchange.guard.keys.util.PGPUtil.isEncryptionKey(key)) {
-                if (key.isMasterKey()) {  // If master key, we will use only if we don't have another encryption key
+            if (com.openexchange.guard.keymanagement.commons.util.PGPUtil.isEncryptionKey(key)) {
+                if (key.isMasterKey() && !com.openexchange.guard.keymanagement.commons.util.PGPUtil.isExpired(key) && !key.hasRevocation()) {  // If master key, we will use only if we don't have another encryption key
                     if (found == null) {
                         found = key;
                     }
                 } else {
                     if (!key.hasRevocation()) {
-                        if (!com.openexchange.guard.keys.util.PGPUtil.isExpired(key)) {
+                        if (!com.openexchange.guard.keymanagement.commons.util.PGPUtil.isExpired(key)) {
                             return (key);
                         }
                     }
@@ -605,7 +611,7 @@ public class PGPUtils {
         if (pgpSignKey == null) {
             throw GuardPGPExceptionCodes.UNABLE_TO_DECODE.create(keys.getUserid(), keys.getContextid());
         }
-        PGPPublicKey pubkey = keys.getPublicKeyRing().getPublicKey(pgpSignKey.getKeyID());  // Get the public key specific to the signing key
+        PGPPublicKey pubkey = keys.getPGPPublicKeyRing().getPublicKey(pgpSignKey.getKeyID());  // Get the public key specific to the signing key
         PGPSignatureGenerator sGen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(pubkey.getAlgorithm(), PGPUtil.SHA512).setProvider("BC"));
 
         sGen.init(PGPSignature.BINARY_DOCUMENT, pgpSignKey);
@@ -623,7 +629,7 @@ public class PGPUtils {
         builder.setWithIntegrityPacket(true);
         PGPEncryptedDataGenerator encryptedDataGenerator = new PGPEncryptedDataGenerator(builder);
         for (int i = 0; i < recipients.size(); i++) {
-            BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(getCryptKey(recipients.get(i).getPgpring()));
+            BcPublicKeyKeyEncryptionMethodGenerator encKeyGen = new BcPublicKeyKeyEncryptionMethodGenerator(getCryptKey(recipients.get(i).getPGPPublicKeyRing()));
             encryptedDataGenerator.addMethod(encKeyGen);
         }
         OutputStream encryptedOut = encryptedDataGenerator.open(out, new byte[4028]);
@@ -674,14 +680,14 @@ public class PGPUtils {
             out = new ArmoredOutputStream(out);
         }
 
-        int algorithm = com.openexchange.guard.keys.util.PGPUtil.getSigningKey(key.getPGPSecretKeyRing()).getPublicKey().getAlgorithm();
+        int algorithm = com.openexchange.guard.keymanagement.commons.util.PGPUtil.getSigningKey(key.getPGPSecretKeyRing()).getPublicKey().getAlgorithm();
         PGPSignatureGenerator sgen = new PGPSignatureGenerator(new JcaPGPContentSignerBuilder(algorithm, PGPUtil.SHA512).setProvider("BC"));
         PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
         PGPPrivateKey pgpSignKey;
         try {
-        	pgpSignKey = pgpKeyService.getPGPSignKey(key.getPGPSecretKeyRing(), password, key.getSalt());
+            pgpSignKey = pgpKeyService.getPGPSignKey(key.getPGPSecretKeyRing(), password, key.getSalt());
         } catch (OXException ex) {
-        	throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+            throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
 
         sgen.init(PGPSignature.BINARY_DOCUMENT, pgpSignKey);
@@ -713,24 +719,4 @@ public class PGPUtils {
         GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.AES_CBC);
         return (cipherService.decrypt(epass, token));
     }
-
-    /**
-     * Verify that the specified password is correct (try getting and decoding the PGP private key)
-     *
-     * @param password The password to verify
-     * @param salt The salt
-     * @param secretKeyring The secret key ring
-     * @return true if the password is correct; false otherwise
-     */
-    public static boolean verifyPassword(String password, String salt, PGPSecretKeyRing secretKeyring) {
-        if (password == null) {
-            return false;
-        }
-        try {
-            PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
-            return pgpKeyService.getPGPPrivateKey(password, salt, secretKeyring) != null;
-        } catch (Exception e) {
-            return false;
-        }
-    }
 }
