@@ -49,13 +49,9 @@
 
 package com.openexchange.guard.pgp;
 
-import java.net.URLEncoder;
 import java.security.SignatureException;
-import java.util.ArrayList;
 import java.util.Date;
 import java.util.Iterator;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.net.util.Base64;
 import org.bouncycastle.bcpg.attr.ImageAttribute;
 import org.bouncycastle.openpgp.PGPException;
@@ -70,55 +66,13 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
-import com.openexchange.exception.OXException;
-import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.common.util.LongUtil;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.util.PGPUtil;
-import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.keymanagement.commons.util.PGPUtil;
 
 public class PgpHandler {
 
     private static Logger LOG = LoggerFactory.getLogger(PgpHandler.class);
 
-    /**
-     * Display Armor output of PGP Key Ring from OX user
-     *
-     * @param request
-     * @param response
-     * @throws OXException
-     */
-    public void getKey(HttpServletRequest request, HttpServletResponse response) throws OXException {
-        String email = ServletUtils.getStringParameter(request, "email", true);
-        if (!email.contains("@")) {
-            LOG.info("Bad email format");
-            ServletUtils.sendNotAcceptable(response, "Bad email format");
-            return;
-        }
-        ;
-        String download = ServletUtils.getStringParameter(request, "download");
-        try {
-            GuardKeyService keyService = Services.getService(GuardKeyService.class);
-            GuardKeys keys = keyService.getKeysFromEmail(email);
-            if (keys != null) {
-                if (download != null) {
-                    String filename = "public.asc";  // Default filename
-                    Iterator it = keys.getPublicKeyRing().getPublicKey().getUserIDs(); // Change filename to first ID if avail
-                    if (it.hasNext()) {
-                        filename = ((String) it.next()) + ".asc";
-                    }
-                    response.setHeader("Content-Disposition", "attachment; filename*=UTF-8''" + URLEncoder.encode(filename, "UTF-8"));
-                }
-                LOG.info("Key retrieved for email " + email);
-                ServletUtils.sendHtmlOK(response, keys.exportPGPPublicKeyRing());
-            }
-        } catch (Exception ex) {
-            LOG.error("Error getting key for " + email, ex);
-            ServletUtils.sendNotAcceptable(response, "Error processing request");
-        }
-    }
-
     /**
      * Return JsonArray of info for PGPSecretKeyRing
      *
@@ -148,14 +102,6 @@ public class PgpHandler {
         return (keyRingData);
     }
 
-    public static JsonArray getKeyInfo(ArrayList<PGPPublicKeyRing> pkeys) throws SignatureException, PGPException {
-        JsonArray data = new JsonArray();
-        for (int i = 0; i < pkeys.size(); i++) {
-            data.add(getKeyInfo(pkeys.get(i)));
-        }
-        return (data);
-    }
-
     /**
      * Print the user info for a PGP public key ring with userid escaped for display
      * @param pkey
@@ -185,7 +131,7 @@ public class PgpHandler {
             pubKey.addProperty("Key", LongUtil.longToHexStringTruncated(key.getKeyID()));
             pubKey.addProperty("KeyID", LongUtil.longToHexString(key.getKeyID()));
             pubKey.addProperty("KeyLong", Long.toString(key.getKeyID()));
-            pubKey.addProperty("Fingerprint", PGPUtil.getFingerPrintString(key.getFingerprint()));
+            pubKey.addProperty("Fingerprint", PGPUtil.getFingerPrintInBlocks(key.getFingerprint()));
             pubKey.addProperty("Created", key.getCreationTime().toString());
             pubKey.addProperty("Master", key.isMasterKey());
             pubKey.addProperty("Encryption", PGPUtil.isEncryptionKey(key));
