@@ -78,14 +78,14 @@ import org.slf4j.LoggerFactory;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.bad.GuardBadStorage;
-import com.openexchange.guard.bruteForceDetection.GuardBruteForceDetectionExceptionCodes;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.common.util.JsonUtil;
+import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.file.FileTyper;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.dao.RecipKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
 import com.openexchange.guard.mail.Attachment;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
@@ -251,11 +251,11 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     * @param id the id to check
     * @throws OXException if a bruteforce attempt has been detected
     */
-   private void checkForBruteForce(String id) throws OXException {
+   private void checkForBruteForce(int userid, int cid, String password, String ip) throws OXException {
        //Check for BF
-       GuardBadStorage badService = Services.getService(GuardBadStorage.class);
-       if(badService.isBad(id)) {
-           throw GuardBruteForceDetectionExceptionCodes.ACCOUNT_LOCKED.create();
+       GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
+       if(antiabuse.blockLogin(userid, cid, password, ip)) {
+           throw GuardAuthExceptionCodes.LOCKOUT.create();
        }
    }
 
@@ -265,14 +265,14 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     * @param id the id to add the attempt for
     * @throws OXException due an error
     */
-   private void countBruteForceAttempt(String id) throws OXException {
-       GuardBadStorage badService = Services.getService(GuardBadStorage.class);
-       badService.addBad(id);
+   private void countBruteForceAttempt(int userid, int cid, String password, String ip) throws OXException {
+       GuardAntiAbuseService badService = Services.getService(GuardAntiAbuseService.class);
+       badService.reportLogin(false, userid, cid, password, ip);
    }
 
    private String getFrom (MimeMessage msg) throws MessagingException {
 	   Address[] fromArray = msg.getFrom();
-	   if (fromArray.length > 0) {
+	   if (fromArray != null && fromArray.length > 0) {
 		   InternetAddress from = new InternetAddress(fromArray[0].toString());
 		   return from.getAddress();
 	   }
@@ -280,10 +280,10 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
    }
 
     @Override
-    public PGPDecryptionResult decryptMimeEmail(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int userId, int contextId, String password) throws OXException {
+    public PGPDecryptionResult decryptMimeEmail(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int userId, int contextId, String password, String remoteIp) throws OXException {
 
         try {
-            checkForBruteForce(cookie.getJSESSIONID());
+            checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the encrypted mime email
             MimeMessage message = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
@@ -300,7 +300,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(cookie.getJSESSIONID());
+                countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -310,9 +310,9 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     }
 
     @Override
-    public PGPDecryptionResult decryptInlineEmail(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password) throws OXException {
+    public PGPDecryptionResult decryptInlineEmail(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
         try {
-            checkForBruteForce(cookie.getJSESSIONID());
+        	checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the Inline Email
             String jsonString = new Api(cookie, session, userAgent).getMail(emailId, emailFolder);
@@ -330,7 +330,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(cookie.getJSESSIONID());
+            	countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -345,10 +345,10 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
      * @see com.openexchange.guard.pgp.decryption.PGPMimeDecryptionService#DecryptMimeAttachment(java.lang.String, java.lang.String, java.lang.String, int, int, java.lang.String, java.io.OutputStream)
      */
     @Override
-    public PGPDecryptionResult decryptMimeAttachmentByName(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentName, int userId, int contextId, String password) throws OXException {
+    public PGPDecryptionResult decryptMimeAttachmentByName(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentName, int userId, int contextId, String password, String remoteIp) throws OXException {
 
         try {
-            checkForBruteForce(cookie.getJSESSIONID());
+        	checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the encrypted mime email
             MimeMessage message = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
@@ -369,7 +369,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(cookie.getJSESSIONID());
+            	countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -379,9 +379,9 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
     }
 
     @Override
-    public PGPDecryptionResult decryptMimeAttachmentById(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentId, int userId, int contextId, String password) throws OXException {
+    public PGPDecryptionResult decryptMimeAttachmentById(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
         try {
-            checkForBruteForce(emailFolder + "/" + emailId + "a:" + attachmentId);
+        	checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Getting the encrypted mime email
             MimeMessage message = getMimeEMail(cookie, session, userAgent, emailFolder, emailId);
@@ -403,7 +403,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch(OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(cookie.getJSESSIONID());
+            	countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -418,10 +418,10 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
      * @see com.openexchange.guard.pgp.decryption.PGPDecryptionService#DecryptInlineAttachment()
      */
     @Override
-    public PGPDecryptionResult decryptInlineAttachment(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password) throws OXException {
+    public PGPDecryptionResult decryptInlineAttachment(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int userId, int contextId, String password, String remoteIp) throws OXException {
 
         try {
-            checkForBruteForce(emailFolder + "/" + emailId + "a:" + attachmentId);
+        	checkForBruteForce(userId, contextId, password, remoteIp);
 
             //Get the encrypted attachment
             Api api = new Api(cookie, session, userAgent);
@@ -444,7 +444,7 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
         }
         catch (OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(emailFolder + "/" + emailId + "a:" + attachmentId);
+            	countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -455,19 +455,18 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
 
 
     @Override
-    public JsonObject decryptMimeAttachmentToDrive(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentName, int folderId, String fileName, String description, int userId, int contextId, String password, AttachmentSaveMode saveMode) throws OXException {
+    public JsonObject decryptMimeAttachmentToDrive(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, String attachmentName, int folderId, String fileName, String description, int userId, int contextId, String password, AttachmentSaveMode saveMode, String remoteIp) throws OXException {
         try {
-            checkForBruteForce(emailFolder + "/" + emailId + "a:" + attachmentName);
-
+            checkForBruteForce(userId, contextId, password, remoteIp);
             //Decrypt the mime attachment
-            PGPDecryptionResult decryptionResult = decryptMimeAttachmentByName(cookie, session, userAgent, emailFolder, emailId, attachmentName, userId, contextId, password);
+            PGPDecryptionResult decryptionResult = decryptMimeAttachmentByName(cookie, session, userAgent, emailFolder, emailId, attachmentName, userId, contextId, password, remoteIp);
             //Save it as new item into drive
 
             return saveToDrive(decryptionResult.getInputStream(), cookie, session, userAgent, folderId, fileName, description, userId, contextId, saveMode);
         }
         catch (OXException e) {
             if(e.getExceptionCode() == GuardPGPExceptionCodes.BAD_PASSWORD_ERROR) {
-                countBruteForceAttempt(emailFolder + "/" + emailId + "a:" + attachmentName);
+            	countBruteForceAttempt(userId, contextId, password, remoteIp);
             }
             throw e;
         }
@@ -482,10 +481,10 @@ public class GuardEMailDecryptionServiceImpl implements GuardEMailDecryptionServ
      * @see com.openexchange.guard.pgp.decryption.GuardDecryptionService#DecryptAttachmentToDrive()
      */
     @Override
-    public JsonObject decryptInlineAttachmentToDrive(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int folderId, String fileName, String description, int userId, int contextId, String password, AttachmentSaveMode saveMode) throws OXException {
+    public JsonObject decryptInlineAttachmentToDrive(OxCookie cookie, String session, String userAgent, String emailFolder, String emailId, int attachmentId, int folderId, String fileName, String description, int userId, int contextId, String password, AttachmentSaveMode saveMode, String remoteIp) throws OXException {
         try {
             //Decrypt the inline attachment
-            PGPDecryptionResult decryptionResult = decryptInlineAttachment(cookie, session, userAgent, emailFolder, emailId, attachmentId, userId, contextId, password);
+            PGPDecryptionResult decryptionResult = decryptInlineAttachment(cookie, session, userAgent, emailFolder, emailId, attachmentId, userId, contextId, password, remoteIp);
             //Save it as new item into drive
             return saveToDrive(decryptionResult.getInputStream(), cookie, session, userAgent, folderId, fileName, description, userId, contextId, saveMode);
         } catch (NoSuchProviderException | IOException | PGPException e) {
