@@ -12,6 +12,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.codec.net.URLCodec;
 import com.google.gson.JsonArray;
+import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
 import com.openexchange.exception.Category;
@@ -20,7 +21,7 @@ import com.openexchange.guard.common.java.Strings;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.translation.GuardTranslationService;
-import static com.openexchange.guard.servlets.util.UserLocaleUtil.*;
+import static com.openexchange.guard.servlets.util.ServletLocaleUtil.*;
 
 public class GuardErrorResponseRenderer {
 
@@ -48,14 +49,25 @@ public class GuardErrorResponseRenderer {
     private static final Pattern PATTERN_CONTROL = Pattern.compile("[\\x00-\\x1F\\x7F]");
     private static final Pattern PATTERN_DSLASH = Pattern.compile("(?://+)");
     private final int errorResponseCode;
+    private final boolean wrapErrorInArray;
 
     /**
      * Initializes a new {@link GuardErrorResponseRenderer}.
-     * 
+     *
      * @param errorResponseCode The response code which will be send to the client in case of an error
      */
     public GuardErrorResponseRenderer(int errorResponseCode) {
+        this(errorResponseCode, false);
+    }
+
+    /**
+     * Initializes a new {@link GuardErrorResponseRenderer}.
+     * @param errorResponseCode The response code which will be send to the client in case of an error
+     * @param wrapErrorInArray True in order to wrap the error in an array (legacy API), false otherwise
+     */
+    public GuardErrorResponseRenderer(int errorResponseCode, boolean wrapErrorInArray) {
         this.errorResponseCode = errorResponseCode;
+        this.wrapErrorInArray = wrapErrorInArray;
     }
 
     /**
@@ -87,7 +99,7 @@ public class GuardErrorResponseRenderer {
 
     /**
      * Internal method to check if the client requested JSON response
-     * 
+     *
      * @param request the client's request
      * @return true, if the client requested a JSON response, false otherwise
      */
@@ -289,9 +301,32 @@ public class GuardErrorResponseRenderer {
                 writer.close();
             }
         } else {
-            JsonArray errorObjects = new JsonArray();
-            errorObjects.add(errorObject);
-            ServletUtils.sendJson(response, errorObjects);
+            //Writing error as plain JSON
+            JsonElement ret = null;
+            if(this.wrapErrorInArray) {
+                JsonArray errorObjects = new JsonArray();
+                errorObjects.add(errorObject);
+                ret = errorObjects;
+            }
+            else {
+                ret = errorObject;
+            }
+            PrintWriter writer = null;
+            try {
+                try {
+                    writer = response.getWriter();
+                } catch (IllegalStateException e1) {
+                    //It's possible that the underlying logic did not use getWriter() but getOutputStream(); And only one is allowed.
+                    writer = new PrintWriter(new OutputStreamWriter(response.getOutputStream(), response.getCharacterEncoding()));
+                }
+                response.setContentType("application/json; charset=UTF-8");
+                // response.addHeader("Access-Control-Allow-Origin", "*");
+                writer.write(ret.toString());
+            } finally {
+                if (writer != null) {
+                    writer.close();
+                }
+            }
         }
     }
 }
