@@ -54,8 +54,16 @@ import java.util.Arrays;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import com.openexchange.exception.OXException;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.antiabuse.AntiAbuseWrapper;
 import com.openexchange.guard.logging.GuardLogProperties;
+import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.oxapi.OxCookie;
+import com.openexchange.guard.servlets.authentication.AuthenticationDataExtractor;
 import com.openexchange.guard.servlets.authentication.GuardAuthenticationHandler;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
 import com.openexchange.guard.servlets.authentication.GuestSessionValidator;
@@ -183,6 +191,55 @@ public abstract class GuardServletAction {
         LOG.info(String.format("Command sent \"%s\" from IP %s", ServletUtils.getStringParameter(request, "action"), ServletUtils.getClientIP(request)));
     }
 
+    /**
+     * Gets the password from a given request.
+     *
+     * This will try to get the password from parameter, from authentication-token, or from epassword parameter
+     *
+     * @param request The request to get the password from
+     * @return The password from the given request, or null if no password was found
+     * @throws OXException
+     */
+    protected String getPassword(HttpServletRequest request) throws OXException {
+        return new AuthenticationDataExtractor().getPassword(request, new OxCookie(request.getCookies()));
+    }
+
+    /**
+     * Gets the password from a given request.
+     *
+     * This will try to get the password from parameter, from authentication-token, or from epassword parameter
+     *
+     * @param request The request to get the password from
+     * @return The password from the given request, or null if no password was found
+     * @throws OXException
+     */
+    protected String requirePassword(HttpServletRequest request) throws OXException {
+        String password = getPassword(request);
+        if(password == null) {
+            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("password or auth");
+        }
+        return password;
+    }
+
+    /**
+     * Gets a helper/simplified wrapper around {@link GuardAntiAbuseService} for handling failed login attempts and lockouts.
+     *
+     * @param keys The keys
+     * @param password The password of the keys
+     * @param userSession The user session
+     * @return The helper for handling failed login attempts and lockouts.
+     * @throws OXException
+     */
+    protected AntiAbuseWrapper getAntiAbuseWrapper(GuardKeys keys, String password, GuardUserSession userSession) throws OXException {
+        GuardAntiAbuseService antiAbuse = Services.getService(GuardAntiAbuseService.class);
+        return new AntiAbuseWrapper(antiAbuse,
+            keys,
+            userSession.getContextId(),
+            userSession.getUserId(),
+            password,
+            userSession.getConnectionInformation().getRemoteAddress());
+    }
+
     /**
      * Template method which allows implementation of the action execution by subclasses
      *
