@@ -57,10 +57,9 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.servlets.callback.CallbackServlet;
 import com.openexchange.guard.servlets.demo.DemoServlet;
-import com.openexchange.guard.servlets.drive.DriveServlet;
-import com.openexchange.guard.servlets.drive.upload.DriveUploadServlet;
 import com.openexchange.guard.servlets.guest.GuestServlet;
 import com.openexchange.guard.servlets.guestreader.GuestReaderServlet;
+import com.openexchange.guard.servlets.keymanagement.KeymanagementServlet;
 import com.openexchange.guard.servlets.keyretrieval.KeyRetrievalServlet;
 import com.openexchange.guard.servlets.login.LoginServlet;
 import com.openexchange.guard.servlets.mail.MailServlet;
@@ -84,12 +83,11 @@ public class GuardServlets {
 
     private static final String GUARD_LOGIN_SERVLET_PATH = "/oxguard/login";
     private static final String GUARD_PING_SERVLET_PATH = "/oxguard/ping";
+    private static final String GUARD_KEY_MANAGEMENT_SERVLET_PATH = "/oxguard/keys";
     private static final String GUARD_PGP_CORE_SERVLET_PATH = "/oxguard/pgpcore";
     private static final String GUARD_PGP_SERVLET_PATH = "/oxguard/pgp";
     private static final String GUARD_PGPMAIL_SERVLET_PATH = "/oxguard/pgpmail";;
     private static final String GUARD_MAIL_SERVLET_PATH = "/oxguard/mail";;
-    private static final String GUARD_DRIVE_SERVLET_PATH = "/oxguard/file";
-    private static final String GUARD_DRIVE_UPLOAD_SERVLET_PATH = "/oxguard/files";
     private static final String GUARD_SETTINGS_SERVLET_PATH = "/oxguard/settings";
     private static final String GUARD_GUEST_SERVLET_PATH = "/oxguard/guest";
     private static final String GUARD_KEY_RETRIEVAL_SERVLET_PATH = "/oxguard/retrieve";
@@ -101,7 +99,7 @@ public class GuardServlets {
 
     /**
      * Registers OX Guard servlets to the given service
-     * 
+     *
      * @param httpService The service where to register the servlets
      * @throws NamespaceException
      * @throws ServletException
@@ -113,6 +111,7 @@ public class GuardServlets {
             return;
         }
         httpService.registerServlet(GUARD_PING_SERVLET_PATH, new PingServlet(), null, null);
+        httpService.registerServlet(GUARD_KEY_MANAGEMENT_SERVLET_PATH, new KeymanagementServlet(), null, null);
         httpService.registerServlet(GUARD_PGP_CORE_SERVLET_PATH, new PGPCoreServlet(), null, null);
         httpService.registerServlet(GUARD_PGP_SERVLET_PATH, new PGPServlet(), null, null);
         httpService.registerServlet(GUARD_PGPMAIL_SERVLET_PATH, new PGPMailServlet(), null, null);
@@ -120,8 +119,6 @@ public class GuardServlets {
         httpService.registerServlet(GUARD_LOGIN_SERVLET_PATH, new LoginServlet(), null, null);
         httpService.registerServlet(GUARD_GUEST_SERVLET_PATH, new GuestServlet(), null, null);
         httpService.registerServlet(GUARD_KEY_RETRIEVAL_SERVLET_PATH, new KeyRetrievalServlet(), null, null);
-        httpService.registerServlet(GUARD_DRIVE_SERVLET_PATH, new DriveServlet(), null, null);
-        httpService.registerServlet(GUARD_DRIVE_UPLOAD_SERVLET_PATH, new DriveUploadServlet(), null, null);
         httpService.registerServlet(GUARD_SETTINGS_SERVLET_PATH, new SettingsServlet(), null, null);
         httpService.registerServlet(GUARD_SUPPORT_SERVLET_PATH, new SupportServlet(), null, null);
         httpService.registerServlet(GUARD_DEMO_SERVLET_PATH, new DemoServlet(), null, null);
@@ -132,7 +129,7 @@ public class GuardServlets {
 
     /**
      * Unregisters OX Guard servlets from the given service
-     * 
+     *
      * @param httpService The service to unregister the servlets from
      */
     public static void unregisterServlets(HttpService httpService) {
@@ -148,8 +145,6 @@ public class GuardServlets {
         httpService.unregister(GUARD_LOGIN_SERVLET_PATH);
         httpService.unregister(GUARD_GUEST_SERVLET_PATH);
         httpService.unregister(GUARD_KEY_RETRIEVAL_SERVLET_PATH);
-        httpService.unregister(GUARD_DRIVE_SERVLET_PATH);
-        httpService.unregister(GUARD_DRIVE_UPLOAD_SERVLET_PATH);
         httpService.unregister(GUARD_SETTINGS_SERVLET_PATH);
         httpService.unregister(GUARD_SUPPORT_SERVLET_PATH);
         httpService.unregister(GUARD_DEMO_SERVLET_PATH);
