@@ -53,6 +53,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.inputvalidation.RangeInputValidator;
 import com.openexchange.guard.mail.SignMime;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
@@ -70,7 +71,7 @@ public class SignEmailAction extends GuardServletAction {
 
     /**
      * Constructs an UserIdentity from a given authToken
-     * 
+     *
      * @param sessionIdentifier The client identifier
      * @param authToken The authToken
      * @return The decrypted UserIdentifier
@@ -83,9 +84,12 @@ public class SignEmailAction extends GuardServletAction {
 
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
+        RangeInputValidator<Integer> positiveValidator = new RangeInputValidator<Integer>(0, Integer.MAX_VALUE);
+
         //We trust the userId and contextId, because it comes from a backend callback
-        int userId = ServletUtils.getIntParameter(request, "user");
-        int contextId = ServletUtils.getIntParameter(request, "context");
+        final boolean mandatory = true;
+        int userId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "user", mandatory), "user");
+        int contextId = positiveValidator.assertInput(ServletUtils.getIntParameter(request, "context", mandatory), "context");
 
         //Extracting user identity from the authenticationToken
         String password = null;
