@@ -56,6 +56,7 @@ import java.text.SimpleDateFormat;
 import java.util.Enumeration;
 import java.util.Properties;
 import java.util.TimeZone;
+
 import javax.mail.Address;
 import javax.mail.Header;
 import javax.mail.Message.RecipientType;
@@ -67,14 +68,16 @@ import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MimeMessage;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+
 import org.apache.commons.io.IOUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.bad.GuardBadStorage;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
@@ -90,12 +93,14 @@ import com.openexchange.guard.email.storage.ogEmail.EmailStorage;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.handler.ResponseHandler;
-import com.openexchange.guard.internal.Auth;
+import com.openexchange.guard.inputvalidation.EmailValidator;
+import com.openexchange.guard.inputvalidation.UUIDValidator;
 import com.openexchange.guard.internal.UserData;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.GuardMasterKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.services.PasswordChangeService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
@@ -103,6 +108,7 @@ import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.pgp.PGPResult;
 import com.openexchange.guard.pgp.PGPUtils;
 import com.openexchange.guard.pgp.decryption.PGPMimeAttachmentExtractor;
+import com.openexchange.guard.pgp.exceptions.GuardPGPExceptionCodes;
 import com.openexchange.guard.servlets.pgpmail.DecryptedMailResponseFactory;
 import com.openexchange.guard.session.GuardSessionService;
 import com.openexchange.guard.storage.Storage;
@@ -119,15 +125,32 @@ public class Guest {
      * @param cookie
      */
     public void changePass(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws OXException {
-        Auth auth = new Auth();
-        cookie.setJSESSIONID(cookie.getOxReaderID()); // Clear the ox cookie for just reader.
         String authToken = ServletUtils.getStringParameter(request, "auth", true);
+        cookie.setJSESSIONID(cookie.getOxReaderID());  // For guest, use ReaderID
         UserData guestData = new UserData(authToken, cookie);
-        if (auth.changepass(request, response, guestData.getUserid(), guestData.getCid(), cookie) != null) {
-            response.setStatus(HttpServletResponse.SC_OK);
-        } else {
-            ServletUtils.sendNotAcceptable(response, "Bad password");
+        JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
+        PasswordChangeService passService = Services.getService(PasswordChangeService.class);
+        String newpass = JsonUtil.getStringFromJson(json, "newpass", true).trim();
+        String question = "";
+        if (json.has("question")) {// Sent with new question and answer?
+            question = json.get("question").getAsString();
         }
+        String answer = "";
+        if (json.has("answer")) {
+            answer = json.get("answer").getAsString();
+        }
+        String email = "";
+        if (json.has("email")) {
+        	email = new EmailValidator().assertInput(json.get("email").getAsString());
+            answer = json.get("email").getAsString();
+            if (!answer.equals("")) {
+                question = "e";
+            }
+        }
+        String oldpass = "";
+        oldpass = JsonUtil.getStringFromJson(json, "oldpass", true);
+        String result = passService.changePassword(guestData.getUserid(), guestData.getCid(), email, oldpass, newpass, question, answer, cookie.getOxReaderID());
+        ServletUtils.sendOK(response, "application,json", result);
     }
 
     /**
@@ -161,6 +184,7 @@ public class Guest {
             itemid = ServletUtils.getStringParameter(request, "email", true);
         }
         if (itemid.startsWith("pgp")) {
+            itemid = new UUIDValidator("pgp-").assertInput(itemid, "itemid");
             String auth = ServletUtils.getStringParameter(request, "auth", true);
             cookie.setJSESSIONID(cookie.getOxReaderID()); // In case person uses both reader and OX main, we need to clear out the previous cookie
             UserData data = new UserData(auth, cookie);
@@ -177,7 +201,7 @@ public class Guest {
                         result = PGPUtils.decryptFile(in, data.getUserid(), data.getCid(), data.getEncr_password());
 
                     } catch (OXException ex) {
-                        if (ex.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD)) {
+                        if (ex.similarTo(GuardAuthExceptionCodes.BAD_PASSWORD) || ex.similarTo(GuardPGPExceptionCodes.BAD_PASSWORD_ERROR)) {
                             in.close();
                             ServletUtils.sendNotAcceptable(response, "Bad password");
                             return;
@@ -203,7 +227,7 @@ public class Guest {
                                     if (download) {
                                         response.setContentType(decryptedAttachment.getContentType());
                                         response.setHeader("Content-Disposition", "attachment; filename=\"" + filename + "\"");
-                                        response.addHeader("Access-Control-Allow-Origin", "*");
+                                        // response.addHeader("Access-Control-Allow-Origin", "*");
                                         response.setStatus(HttpServletResponse.SC_OK);
                                     } else {
                                         response.setContentType(decryptedAttachment.getContentType());
@@ -382,7 +406,7 @@ public class Guest {
      * @throws IOException
      */
     public void getQuestion(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws OXException {
-        String email = ServletUtils.getStringParameter(request, "email", true);
+        String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, "email", true), "email");
         EmailStorage ogEmailStorage = Services.getService(EmailStorage.class);
 
         //Getting the mail mapping
@@ -414,18 +438,22 @@ public class Guest {
      * @throws OXException
      */
     public void resetPassword(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws OXException {
-        String email = ServletUtils.getStringParameter(request, "email", true);
+        String email = new EmailValidator().assertInput(ServletUtils.getStringParameter(request, "email", true), "email");
         String answer = ServletUtils.getStringParameter(request, "answer", true);
         String lang = ServletUtils.getStringParameter(request, "language");
-        int templId = ServletUtils.getIntParameter(request, "templid");
+        Integer templId = ServletUtils.getIntParameter(request, "templid");
+        if(templId == null) {
+            templId = 0;
+        }
+
         String question = "";
 
         int cid = 0;
         int userid = 0;
         try {
             GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-            GuardBadStorage badStorage = Services.getService(GuardBadStorage.class);
-            if (badStorage.isBad("reset-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
+            GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
+            if (antiabuse.isBad("reset-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
                 ServletUtils.sendHtmlOK(response, "lockout");
                 return;
             }
@@ -461,13 +489,13 @@ public class Guest {
                 answer = answer.toLowerCase().replace(" ", "");
                 if (!prevanswer.equals(answer)) {
                     ServletUtils.sendHtmlOK(response, "No Match");
-                    badStorage.addBad("reset-" + email);
+                    antiabuse.addBad("reset-" + email);
                     return;
                 }
             }
             reset(email, lang, templId, cid, userid, request.getServerName());
 
-            badStorage.removeBad(email);
+            antiabuse.removeBad(email);
             ServletUtils.sendHtmlOK(response, "OK");
         } catch (Exception ex) {
             LOG.error("Error resetting password for email account " + email, ex);
