@@ -71,10 +71,13 @@ public class GuestServlet extends AbstractGuardServlet {
     private static final String GET_GET_ATTACHMENT_ACTION = "getattach";
     private static final String GET_PASSWORD_RESET_QUESTION = "getquestion";
     private static final String GET_RESET_PASSWORD_ACTION = "resetpassword";
+    private static final String GET_RESET_ACCOUNT = "resetaccount";
     private static final String GET_CID_ATTACHMENT_ACTION = "getattachcid";
     private static final String POST_CHANGE_PASSWORD_ACTION = "changepass";
     private static final String POST_GET_MAIL_ACTION = "getmail";
     private static final String POST_UPLOAD_ENCRYPTED_MAIL_ACTION = "upload";
+    private static final String POST_DO_RESET = "doresetaccount";
+    private static final String POST_FIRST_PASS = "firstpass";
 
     private final HashMap<String, GuardServletAction> getActions;
     private final HashMap<String, GuardServletAction> postActions;
@@ -91,12 +94,15 @@ public class GuestServlet extends AbstractGuardServlet {
         getActions.put(GET_PASSWORD_RESET_QUESTION, new GetPasswordResetQuestion());
         getActions.put(GET_RESET_PASSWORD_ACTION, new ResetPasswordAction());
         getActions.put(GET_CID_ATTACHMENT_ACTION, new GetCidAttachmentAction().setAuthenticationHandler(uiSessionAuthentication));
+        getActions.put(GET_RESET_ACCOUNT, new ResetGuardAccountAction());
 
         //POST
         postActions = new HashMap<String, GuardServletAction>();
         postActions.put(POST_CHANGE_PASSWORD_ACTION, new ChangePasswordAction().setAuthenticationHandler(uiSessionAuthentication));
         postActions.put(POST_GET_MAIL_ACTION, new GetMailAction().setAuthenticationHandler(uiSessionAuthentication));
         postActions.put(POST_UPLOAD_ENCRYPTED_MAIL_ACTION, new UploadEncryptedMailAction().setAuthenticationHandler(uiSessionAuthentication));
+        postActions.put(POST_DO_RESET, new DoResetGuardAccount());
+        postActions.put(POST_FIRST_PASS, new GuestFirstPasswordAction());
     }
 
     /*
