@@ -58,7 +58,7 @@ import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
 import com.openexchange.exception.OXException;
-import com.openexchange.guard.bad.GuardBadStorage;
+import com.openexchange.guard.antiabuse.GuardAntiAbuseService;
 import com.openexchange.guard.cipher.GuardCipherAlgorithm;
 import com.openexchange.guard.cipher.GuardCipherFactoryService;
 import com.openexchange.guard.cipher.GuardCipherService;
@@ -67,11 +67,12 @@ import com.openexchange.guard.common.util.JsonUtil;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.handler.ResponseHandler;
+import com.openexchange.guard.inputvalidation.EmailValidator;
 import com.openexchange.guard.internal.UserData;
-import com.openexchange.guard.keys.PGPKeyService;
-import com.openexchange.guard.keys.dao.DeletedKey;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.DeletedKeysStorage;
+import com.openexchange.guard.keymanagement.commons.DeletedKey;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.commons.export.KeyExportUtil;
+import com.openexchange.guard.keymanagement.storage.DeletedKeysStorage;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.OxCookie;
 import com.openexchange.guard.session.GuardSessionService;
@@ -99,13 +100,13 @@ public class KeyRetriever {
         JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
         int userid = JsonUtil.getIntFromJson(json, "userid", true);
         int cid = JsonUtil.getIntFromJson(json, "cid", true);
-        String email = JsonUtil.getStringFromJson(json, "username", true);
+        final String email = new EmailValidator().assertInput(JsonUtil.getStringFromJson(json, "username", true), "username");
         String salt = JsonUtil.getStringFromJson(json, "salt", true);
         String password = JsonUtil.getStringFromJson(json, "password", true);
         JsonObject returnJson = new JsonObject();
-        GuardBadStorage badStorage = Services.getService(GuardBadStorage.class);
+        GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        if (badStorage.isBad("retr-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
+        if (antiabuse.isBad("retr-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
             LOG.warn("Account lockout for key retrieval");
             sendBad(response, "lockout");
             return;
@@ -118,7 +119,7 @@ public class KeyRetriever {
             return;
         }
         if (!keys.get(0).verifyPassword(password)) {
-            badStorage.addBad("retr-" + email);
+            antiabuse.addBad("retr-" + email);
             LOG.warn("Bad password attempt for key retrieval");
             sendBad(response, "Bad Password");
             return;
@@ -134,7 +135,7 @@ public class KeyRetriever {
         }
 
         if (!match) {
-            badStorage.addBad("retr-" + email);
+            antiabuse.addBad("retr-" + email);
             sendBad(response, "bad salt");
             return;
         }
@@ -172,11 +173,11 @@ public class KeyRetriever {
      */
     public void getkeys(HttpServletRequest request, HttpServletResponse response, OxCookie cookie) throws Exception {
         JsonObject json = Services.getService(ResponseHandler.class).getJsonAndDecodeEncryptedPasswords(request);
-        String email = JsonUtil.getStringFromJson(json, "username", true);
+        final String email = new EmailValidator().assertInput(JsonUtil.getStringFromJson(json, "username", true), "username");
         String auth = ServletUtils.getStringParameter(request, "auth", true);
-        GuardBadStorage badStorage = Services.getService(GuardBadStorage.class);
+        GuardAntiAbuseService antiabuse = Services.getService(GuardAntiAbuseService.class);
         GuardConfigurationService configService = Services.getService(GuardConfigurationService.class);
-        if (badStorage.isBad("retr-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
+        if (antiabuse.isBad("retr-" + email, configService.getIntProperty(GuardProperty.badPasswordCount))) {
             ServletUtils.sendNotAcceptable(response, "lockout");
             return;
         }
@@ -184,7 +185,7 @@ public class KeyRetriever {
         UserData userdata = new UserData(auth, cookie);
         if (userdata.getUserid() < 0) {
             ServletUtils.sendNotAcceptable(response, "Bad auth");
-            badStorage.addBad("retr-" + email);
+            antiabuse.addBad("retr-" + email);
             LOG.warn("Bad password attempt for key retrieval");
             return;
         }
@@ -205,7 +206,7 @@ public class KeyRetriever {
         }
         // Verify first password is correct.
         if (!keys.get(0).verifyPassword(userdata.getEncr_password())) {
-            badStorage.addBad("retr-" + email);
+            antiabuse.addBad("retr-" + email);
             ServletUtils.sendNotAcceptable(response, "Bad Password");
             LOG.warn("Bad password attempt for key retrieval");
             return;
@@ -214,11 +215,10 @@ public class KeyRetriever {
         try {
             DeletedKey deletedKey = keys.get(index);
             GuardKeys key = new GuardKeys(deletedKey.getUserId(), deletedKey.getCid(), deletedKey.getSecretKeyRing(), deletedKey.getSalt());
-            PGPKeyService pgpKeyService = Services.getService(PGPKeyService.class);
-            export = pgpKeyService.exportPGPPrivateKey(key, password.equals("") ? userdata.getEncr_password() : password);
+            export = KeyExportUtil.exportPGPPrivateKey(key, password.equals("") ? userdata.getEncr_password() : password);
         } catch (OXException e) {
             ServletUtils.sendNotAcceptable(response, "bad password");
-            badStorage.addBad("retr-" + email);
+            antiabuse.addBad("retr-" + email);
             return;
         }
         LOG.info("Exported previously deleted key for " + email);
