@@ -84,7 +84,7 @@ public class LoginServlet extends AbstractGuardServlet {
 
         //GET
         servletGetActions = new HashMap<String, GuardServletAction>();
-        servletGetActions.put(LOGOUT_ACTION, new LogoutAction());
+        servletGetActions.put(LOGOUT_ACTION, new LogoutAction().setAuthenticationHandler(uiSessionAuthentication));
         servletGetActions.put(RESET_PASSWORD_ACTION, new ResetPasswordAction().setAuthenticationHandler(uiSessionAuthentication));
         servletGetActions.put(GET_SECONDARY_EMAIL_ACTION, new GetSecondaryEmailAction().setAuthenticationHandler(uiSessionAuthentication));
 
