@@ -49,12 +49,19 @@
 
 package com.openexchange.guard.servlets.pgpcore;
 
+import java.io.ByteArrayInputStream;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.List;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.fileupload.FileItemIterator;
-import org.apache.commons.fileupload.servlet.ServletFileUpload;
+import org.apache.commons.fileupload.FileItemStream;
+import org.apache.commons.io.IOUtils;
+import org.apache.commons.io.output.DeferredFileOutputStream;
 import org.slf4j.LoggerFactory;
 import org.slf4j.Logger;
 import com.google.gson.JsonArray;
@@ -62,14 +69,17 @@ import com.google.gson.JsonElement;
 import com.google.gson.JsonObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.util.JsonUtil;
+import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
+import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
 import com.openexchange.guard.osgi.Services;
-import com.openexchange.guard.oxapi.streaming.FileItemInputStream;
 import com.openexchange.guard.pgpcore.services.PGPCryptoService;
+import com.openexchange.guard.pgpcore.services.TokenAuthenticationService;
 import com.openexchange.guard.pgpcore.services.UserIdentity;
 import com.openexchange.guard.servlets.GuardServletAction;
 import com.openexchange.guard.servlets.authentication.GuardUserSession;
-import static com.openexchange.guard.servlets.pgpcore.PGPCoreServletUtil.*;
+import com.openexchange.guard.servlets.fileupload.FileUploadHandler;
+import com.openexchange.guard.servlets.fileupload.JsonFileUploadHandler;
 
 /**
  * {@link EncryptAction}
@@ -81,17 +91,20 @@ public class EncryptAction extends GuardServletAction {
 
     private static final Logger log = LoggerFactory.getLogger(GuardServletAction.class);
     private static final String CONTENT_TYPE_PGP_ENCRYPTED = "application/pgp-encrypted";
+    private static final String JSON_DATA_FIELD_NAME = "json";
+    private static final String DATA_FIELD_NAME = "data";
+    private static final String OPTION_ARMORED = "armored";
 
     /**
      * Parses the recipient list from the given JSON object
-     * 
+     *
      * @param json the JSON object to parse the recipient list from
      * @return A list of recipients parsed from the given JSON object
      * @throws OXException
      */
     private List<String> getRecipientFromJson(JsonObject json) throws OXException {
         JsonArray recipients = JsonUtil.getArrayFromJson(json, "recipients", true);
-        ArrayList<String> ret = new ArrayList<String>();
+        ArrayList<String> ret = new ArrayList<>();
         for (JsonElement recipient : recipients) {
             ret.add(recipient.getAsString());
         }
@@ -100,35 +113,76 @@ public class EncryptAction extends GuardServletAction {
 
     /*
      * (non-Javadoc)
-     * 
+     *
      * @see com.openexchange.guard.servlets.GuardServletAction#doActionInternal(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse, com.openexchange.guard.servlets.authentication.GuardUserSession)
      */
     @Override
     protected void doActionInternal(HttpServletRequest request, HttpServletResponse response, GuardUserSession userSession) throws Exception {
 
-        ServletFileUpload servletFileUpload = createFileUpload();
-        FileItemIterator fileItemIterator = servletFileUpload.getItemIterator(request);
-        try (FileItemInputStream jsonStream = new FileItemInputStream("json", fileItemIterator);
-            FileItemInputStream dataStream = new FileItemInputStream("data", fileItemIterator);) {
+        JsonObject json = null;
+        InputStream dataStream = null;
+        FileUploadHandler fileUploadHandler = new FileUploadHandler(Services.getService(GuardConfigurationService.class));
+        JsonFileUploadHandler jsonFileUploadHandler = new JsonFileUploadHandler(fileUploadHandler);
 
-            //Parsing Json metadata
-            JsonObject json = getJsonFromStream(jsonStream);
-            boolean armored = JsonUtil.getBooleanFromJson(json, "armored");
-            List<String> recipients = getRecipientFromJson(json);
-            UserIdentity signingIdentity = getUserIdentityFromJson(json);
-            if (json.has("user") && signingIdentity == null) {
-                throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+        //Using streaming approach because we do not want large plaintext data to be buffered on disk for parsing.
+        FileItemIterator itemIterator = fileUploadHandler.parseIterator(request);
+        while (itemIterator.hasNext()) {
+            FileItemStream fileItemStream = itemIterator.next();
+            if (fileItemStream.getFieldName().equals(JSON_DATA_FIELD_NAME)) {
+                try (InputStream jsonStream = fileItemStream.openStream()) {
+                    json = jsonFileUploadHandler.getJsonFrom(jsonStream);
+                }
+            } else if (fileItemStream.getFieldName().equals(DATA_FIELD_NAME)) {
+                dataStream = fileItemStream.openStream();
             }
-            
-            //Encrypting the data
-            response.setContentType(CONTENT_TYPE_PGP_ENCRYPTED);
-            PGPCryptoService cryptoService = Services.getService(PGPCryptoService.class);
-            if (signingIdentity != null) {
-                cryptoService.encryptSigned(dataStream, response.getOutputStream(), armored, signingIdentity, recipients);
+
+            if (json != null && dataStream != null) {
+                //we got all we need: prevent that hasNext() skips the dataStream.
+                break;
             }
-            else {
-                cryptoService.encrypt(dataStream, response.getOutputStream(), armored, recipients);
+        }
+
+        if (json != null) {
+            if (dataStream != null) {
+
+                //Parsing the provided Json
+                boolean armored = JsonUtil.getBooleanFromJson(json, OPTION_ARMORED);
+                List<String> recipients = getRecipientFromJson(json);
+                UserIdentity signingIdentity = new UserIdentityJsonParser(Services.getService(TokenAuthenticationService.class), json).parse();
+                if (json.has("user") && signingIdentity == null) {
+                    throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
+                }
+
+                //Encrypting the data to memory or disk.
+                DeferredFileOutputStream outputStream = fileUploadHandler.createOutputStream();
+                PGPCryptoService cryptoService = Services.getService(PGPCryptoService.class);
+                if (signingIdentity != null) {
+                    cryptoService.encryptSigned(dataStream, outputStream, armored, signingIdentity, recipients);
+                } else {
+                    cryptoService.encrypt(dataStream, outputStream, armored, recipients);
+                }
+
+                //Send the data back to the client
+                try (InputStream responseStream = outputStream.isInMemory() ? new ByteArrayInputStream(outputStream.getData()) : new FileInputStream(outputStream.getFile());) {
+                    response.setContentType(CONTENT_TYPE_PGP_ENCRYPTED);
+                    IOUtils.copy(responseStream, response.getOutputStream());
+                } finally {
+                    //Cleanup if encrypted data has been buffered to disk.
+                    if (!outputStream.isInMemory()) {
+                        try {
+                            Files.delete(outputStream.getFile().toPath());
+                        } catch (IOException e) {
+                            //Just log the error
+                            log.error("Error deleting tmp. file {}", outputStream.getFile().toPath());
+                        }
+                    }
+                }
+
+            } else {
+                throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(DATA_FIELD_NAME);
             }
+        } else {
+            throw GuardCoreExceptionCodes.PARAMETER_MISSING.create(JSON_DATA_FIELD_NAME);
         }
     }
 }
