@@ -88,9 +88,15 @@ public class GetAttachmentByIdAction extends GuardServletAction {
             throw GuardCoreExceptionCodes.PARAMETER_MISSING.create("Password or auth missing.");
         }
 
-        //Decrypt the email and get a stream to the decrypted attachment
+        boolean serverAsDownload = ServletUtils.getBooleanParameter(request, "download", false);
+        if (serverAsDownload) {
+            response.setHeader("Content-Disposition", "attachment; filename=\"" + attachmentName + "\"");
+            // response.addHeader("Access-Control-Allow-Origin", "*");
+        }
+
+        //Decrypt the email ant get a stream to the decrypted attachment
         final GuardEMailDecryptionService decryptionService = new GuardEMailDecryptionServiceImpl();
-        final PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentById(cookie, session, userAgent, emailFolder, emailId, contentid, userId, contextId, password);
+        final PGPDecryptionResult decryptionResult = decryptionService.decryptMimeAttachmentById(cookie, session, userAgent, emailFolder, emailId, contentid, userId, contextId, password, ServletUtils.getClientIP(request));
 
         try (InputStream binaryResponse = decryptionResult.getInputStream()) {
             new BinaryResponse(response).send(binaryResponse, serveAsDownload, attachmentName);
