@@ -51,28 +51,18 @@ package com.openexchange.guard.servlets.pgpmail;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
-import java.security.NoSuchAlgorithmException;
 import java.security.SignatureException;
-import java.util.Collection;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.bouncycastle.bcpg.ArmoredOutputStream;
 import org.bouncycastle.openpgp.PGPException;
-import org.bouncycastle.openpgp.PGPPublicKeyRing;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonPrimitive;
-import com.openexchange.exception.OXException;
 import com.openexchange.guard.common.servlets.utils.ServletUtils;
-import com.openexchange.guard.common.util.CipherUtil;
-import com.openexchange.guard.keys.HKPClientService;
-import com.openexchange.guard.keys.PublicKeyService;
-import com.openexchange.guard.keys.dao.RecipKey;
-import com.openexchange.guard.keys.internal.hkpclient.RemoteKeyResult;
-import com.openexchange.guard.keys.util.PGPUtil;
+import com.openexchange.guard.keymanagement.commons.RecipKey;
+import com.openexchange.guard.keymanagement.services.AccountCreationService;
+import com.openexchange.guard.keymanagement.services.RecipKeyService;
 import com.openexchange.guard.osgi.Services;
 import com.openexchange.guard.oxapi.Api;
 import com.openexchange.guard.oxapi.OxCookie;
@@ -89,7 +79,6 @@ import com.openexchange.guard.servlets.authentication.GuardUserSession;
  */
 public class GetPublicKeyByMailAction extends GuardServletAction {
 
-    private static Logger logger = LoggerFactory.getLogger(GetPublicKeyByMailAction.class);
 
     private static final String PARAMETER_CREATE_IF_MISSING = "createIfMissing";
     private static final String PARAMETER_DOWNLOAD = "download";
@@ -140,8 +129,8 @@ public class GetPublicKeyByMailAction extends GuardServletAction {
                     ret.addProperty("data", new String(out.toByteArray()));
                 }
                 else {
-                    if (recipient.getPgpring() != null) {
-                        ret.add("data", PgpHandler.getKeyInfo(recipient.getPgpring()));
+                    if (recipient.getPGPPublicKeyRing() != null) {
+                        ret.add("data", PgpHandler.getKeyInfo(recipient.getPGPPublicKeyRing()));
                     }
                     else {
                         ret.add("data", new JsonArray());
@@ -172,40 +161,13 @@ public class GetPublicKeyByMailAction extends GuardServletAction {
     private ByteArrayOutputStream exportKey(RecipKey recipientKey) throws IOException {
         try (ByteArrayOutputStream out = new ByteArrayOutputStream();
             ArmoredOutputStream arm = new ArmoredOutputStream(out)) {
-            if (recipientKey.getPgpring() != null) {
-                arm.write(recipientKey.getPgpring().getEncoded());
+            if (recipientKey.getPGPPublicKeyRing() != null) {
+                arm.write(recipientKey.getPGPPublicKeyRing().getEncoded());
             }
             return out;
         }
     }
 
-    /**
-     * Internal method to perform a HKP remote search
-     *
-     * @param hkpClientToken a token sent to the HKP server
-     * @param email the email to search a key for
-     * @return The key found, or null if no such key was found
-     * @throws NoSuchAlgorithmException
-     * @throws UnsupportedEncodingException
-     * @throws OXException
-     */
-    private RecipKey remoteHKPSearch(String hkpClientToken, String email) throws OXException {
-        RecipKey ret = null;
-        HKPClientService hkpClient = Services.getService(HKPClientService.class);
-        Collection<RemoteKeyResult> remoteKeys = hkpClient.find(hkpClientToken, email);
-        if (remoteKeys != null && !remoteKeys.isEmpty()) {
-            PGPPublicKeyRing remoteKey = remoteKeys.iterator().next().getRing();
-            if (remoteKey != null) {
-                ret = new RecipKey();
-                ret.setPgpring(remoteKey);
-                ret.setEmail(email);
-                ret.setPgp(true);
-                ret.setExpired(PGPUtil.checkAllExpired(remoteKey));
-            }
-        }
-        return ret;
-    }
-
     /*
      * (non-Javadoc)
      *
@@ -224,28 +186,20 @@ public class GetPublicKeyByMailAction extends GuardServletAction {
         boolean createIfMissing = ServletUtils.getBooleanParameter(request, PARAMETER_CREATE_IF_MISSING);
         boolean serveAsDownload = ServletUtils.getBooleanParameter(request, PARAMETER_DOWNLOAD);
 
-        PublicKeyService publicKeyService = Services.getService(PublicKeyService.class);
-        RecipKey recip = null;
-        if (createIfMissing) {
-            //Creating keys for GUARD user but not for guests, therefore passing remote=true and send=true, because then no guest account will be created;
-            //In addition a remote lookup is missing if remote=true, therefore we need to do a remote HKP lookup here
-            //TODO: refactor this behavior in order to be more intuitive
-            recip = publicKeyService.getPubKey(email, userId, cid, senderEmail, true, true, request.getServerName());
-            if (recip == null) {
-                //Doing a remote lookup because it was missing while searching for keys, because we had to pass (true,true) in order to
-                //not create a guest account, but the downside of the code is that the remote lookup is not executed is this case.
-                //TODO: refactor
-                recip = remoteHKPSearch(CipherUtil.getMD5(senderEmail), email);
-            }
-        }
-        else {
-            //Looking for the requested key; we do not create keys if missing
-            recip = publicKeyService.getPubKey(email, userId, cid, senderEmail, false, false, request.getServerName());
+        //Searching for a key
+        RecipKey recip = Services.getService(RecipKeyService.class).getRecipKey(
+            userId,
+            cid,
+            email);
+
+        //Create not existing key if desired
+        if(createIfMissing && recip != null && recip.isNewKey()) {
+            Services.getService(AccountCreationService.class).createUserFor(recip);
         }
 
         JsonObject jsonResponse = createReponseObject(email, serveAsDownload, recip);
         response.setContentType("application/json; charset=utf-8");
-        response.addHeader("Access-Control-Allow-Origin", "*");
+        // response.addHeader("Access-Control-Allow-Origin", "*");
         response.setStatus(HttpServletResponse.SC_OK);
         response.getWriter().write(jsonResponse.toString());
     }
