@@ -8,8 +8,8 @@ import com.openexchange.exception.OXException;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.keys.dao.DeletedKey;
-import com.openexchange.guard.keys.storage.DeletedKeysStorage;
+import com.openexchange.guard.keymanagement.commons.DeletedKey;
+import com.openexchange.guard.keymanagement.storage.DeletedKeysStorage;
 import com.openexchange.guard.osgi.Services;
 
 /**
