@@ -12,10 +12,10 @@ import com.openexchange.guard.cipher.GuardCipherService;
 import com.openexchange.guard.configuration.GuardConfigurationService;
 import com.openexchange.guard.configuration.GuardProperty;
 import com.openexchange.guard.exceptions.GuardCoreExceptionCodes;
-import com.openexchange.guard.keys.GuardKeyService;
-import com.openexchange.guard.keys.GuardMasterKeyService;
-import com.openexchange.guard.keys.dao.GuardKeys;
-import com.openexchange.guard.keys.storage.KeyTableStorage;
+import com.openexchange.guard.keymanagement.commons.GuardKeys;
+import com.openexchange.guard.keymanagement.services.GuardKeyService;
+import com.openexchange.guard.keymanagement.services.GuardMasterKeyService;
+import com.openexchange.guard.keymanagement.storage.KeyTableStorage;
 import com.openexchange.guard.mailcreator.MailCreatorService;
 import com.openexchange.guard.notification.GuardNotificationService;
 import com.openexchange.guard.osgi.Services;
